@@ -1,11 +1,10 @@
 /*
  *      cook - file construction tool
- *      Copyright (C) 1992-1994, 1997, 1998, 2001, 2006, 2007 Peter Miller;
- *      All rights reserved.
+ *      Copyright (C) 1992-1994, 1997, 1998, 2001, 2006-2009 Peter Miller
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
- *      the Free Software Foundation; either version 2 of the License, or
+ *      the Free Software Foundation; either version 3 of the License, or
  *      (at your option) any later version.
  *
  *      This program is distributed in the hope that it will be useful,
@@ -14,10 +13,8 @@
  *      GNU General Public License for more details.
  *
  *      You should have received a copy of the GNU General Public License
- *      along with this program; if not, write to the Free Software
- *      Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
- *
- * MANIFEST: functions to scan C language files
+ *      along with this program. If not, see
+ *      <http://www.gnu.org/licenses/>.
  */
 
 #include <common/ac/ctype.h>
@@ -62,8 +59,8 @@ directive(char *s, string_list_ty * type1, string_list_ty * type2)
     /*
      * see if it is a #include directive
      */
-    trace(("directive(s = \"%s\", type1 = %08lX, type2 = %08lX)\n{\n",
-            s, type1, type2));
+    trace(("directive(s = \"%s\", type1 = %p, type2 = %p)\n{\n", s, type1,
+        type2));
     assert(*s == '#');
     s++;
     while (isspace(*s))
@@ -167,8 +164,8 @@ lang_c_scan(input_ty *fp, string_list_ty *type1, string_list_ty *type2)
     int             c;
     char            *cp;
 
-    trace(("lang_c_scan(fp = %08lX, type1 = %08lX, type2 = %08lX)\n{\n", fp,
-        type1, type2));
+    trace(("lang_c_scan(fp = %p, type1 = %p, type2 = %p)\n{\n", fp, type1,
+        type2));
     pos = 0;
     max = 100;
     line = mem_alloc(max);
