@@ -1,11 +1,10 @@
 /*
  *      cook - file construction tool
- *      Copyright (C) 1991-1994, 1997, 1998, 2006, 2007 Peter Miller;
- *      All rights reserved.
+ *      Copyright (C) 1991-1994, 1997, 1998, 2006-2008 Peter Miller
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
- *      the Free Software Foundation; either version 2 of the License, or
+ *      the Free Software Foundation; either version 3 of the License, or
  *      (at your option) any later version.
  *
  *      This program is distributed in the hope that it will be useful,
@@ -14,10 +13,8 @@
  *      GNU General Public License for more details.
  *
  *      You should have received a copy of the GNU General Public License
- *      along with this program; if not, write to the Free Software
- *      Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
- *
- * MANIFEST: functions to implement missing ANSI C <string.h> functions
+ *      along with this program. If not, see
+ *      <http://www.gnu.org/licenses/>.
  *
  * This file contains functions for use with non-ANSI conforming systems
  * to implement absent ANSI functionality.
@@ -116,11 +113,8 @@ strcasecmp(s1, s2)
 #ifndef HAVE_STRSIGNAL
 
 char *
-strsignal(n)
-        int     n;
+strsignal(int n)
 {
-        static char buffer[16];
-
         switch (n)
         {
 #ifdef SIGHUP
@@ -217,14 +211,25 @@ strsignal(n)
         case SIGPWR:
                 return "power failure [SIGPWR]";
 #endif /* SIGPWR */
-
-        default:
-                sprintf(buffer, "signal %d", n);
-                return buffer;
         }
+        return 0;
 }
 
 #endif /* !HAVE_STRSIGNAL */
+
+
+const char *
+safe_strsignal(int n)
+{
+    static char buffer[16];
+    const char *s = strsignal(n);
+    if (s && *s)
+        return s;
+    snprintf(buffer, sizeof(buffer), "signal %d", n);
+    return buffer;
+}
+
+
 #ifndef HAVE_STRENDCPY
 
 char *
