@@ -1,11 +1,10 @@
 /*
  *      cook - file construction tool
- *      Copyright (C) 1994, 1997, 1998, 2006, 2007 Peter Miller;
- *      All rights reserved.
+ *      Copyright (C) 1994, 1997, 1998, 2006-2008 Peter Miller
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
- *      the Free Software Foundation; either version 2 of the License, or
+ *      the Free Software Foundation; either version 3 of the License, or
  *      (at your option) any later version.
  *
  *      This program is distributed in the hope that it will be useful,
@@ -14,10 +13,8 @@
  *      GNU General Public License for more details.
  *
  *      You should have received a copy of the GNU General Public License
- *      along with this program; if not, write to the Free Software
- *      Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
- *
- * MANIFEST: insulate against <string.h> vs <strings.h> differences
+ *      along with this program. If not, see
+ *      <http://www.gnu.org/licenses/>.
  */
 
 #ifndef COMMON_AC_STRING_H
@@ -49,6 +46,8 @@
 # endif
 #endif
 
+const char *safe_strsignal(int);
+
 #if STDC_HEADERS || HAVE_STRING_H
 #  include <string.h>
    /* An ANSI string.h and pre-ANSI memory.h might conflict.  */
