@@ -1,11 +1,10 @@
 /*
  *      cook - file construction tool
- *      Copyright (C) 1997, 1998, 2001, 2004, 2006, 2007 Peter Miller;
- *      All rights reserved.
+ *      Copyright (C) 1997, 1998, 2001, 2004, 2006-2009 Peter Miller
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
- *      the Free Software Foundation; either version 2 of the License, or
+ *      the Free Software Foundation; either version 3 of the License, or
  *      (at your option) any later version.
  *
  *      This program is distributed in the hope that it will be useful,
@@ -14,10 +13,8 @@
  *      GNU General Public License for more details.
  *
  *      You should have received a copy of the GNU General Public License
- *      along with this program; if not, write to the Free Software
- *      Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
- *
- * MANIFEST: functions to manipulate error_intls
+ *      along with this program. If not, see
+ *      <http://www.gnu.org/licenses/>.
  */
 
 #include <common/ac/stdio.h>
@@ -35,6 +32,7 @@
 #include <common/progname.h>
 #include <common/quit.h>
 #include <common/star.h>
+#include <common/trace.h>
 #include <common/verbose.h>
 #include <common/wstr.h>
 
@@ -257,7 +255,10 @@ wrap_inner(const wchar_t *s, const wchar_t *end)
         else
             ocol = 8;
 
-        wctomb(NULL, 0);
+        if (wctomb(NULL, 0) == -1)
+        {
+            assert(!"assume success");
+        }
         ep = s;
         break_space = 0;
         break_space_col = 0;
@@ -303,7 +304,10 @@ wrap_inner(const wchar_t *s, const wchar_t *end)
                  * need to reset the wctomb state, it is
                  * not broken.
                  */
-                wctomb(NULL, 0);
+                if (wctomb(NULL, 0) == -1)
+                {
+                    assert(!"assume success");
+                }
             }
 
             /*
@@ -389,7 +393,10 @@ wrap_inner(const wchar_t *s, const wchar_t *end)
         /*
          * Turn the input into a multi byte characters.
          */
-        wctomb(NULL, 0);
+        if (wctomb(NULL, 0) == -1)
+        {
+            assert(!"assume success");
+        }
         while (s < ep)
         {
             wchar_t         c;
@@ -430,7 +437,10 @@ wrap_inner(const wchar_t *s, const wchar_t *end)
                  * need to reset the wctomb state, it is
                  * not broken.
                  */
-                wctomb(NULL, 0);
+                if (wctomb(NULL, 0) == -1)
+                {
+                    assert(!"assume success");
+                }
             }
             tp += nbytes;
         }
@@ -595,6 +605,11 @@ verbose_intl(sub_context_ty *scp, char *s)
 
     if (need_to_delete)
         sub_context_delete(scp);
+
+#ifdef DEBUG
+    /* Silence gcc warning */
+    (void)trace_pretest_result;
+#endif
 }
 
 
