@@ -1,11 +1,10 @@
 /*
  *      cook - file construction tool
- *      Copyright (C) 1994, 1996, 1997, 1999, 2006, 2007 Peter Miller;
- *      All rights reserved.
+ *      Copyright (C) 1994, 1996, 1997, 1999, 2006-2009 Peter Miller
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
- *      the Free Software Foundation; either version 2 of the License, or
+ *      the Free Software Foundation; either version 3 of the License, or
  *      (at your option) any later version.
  *
  *      This program is distributed in the hope that it will be useful,
@@ -14,15 +13,12 @@
  *      GNU General Public License for more details.
  *
  *      You should have received a copy of the GNU General Public License
- *      along with this program; if not, write to the Free Software
- *      Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
- *
- * MANIFEST: functions to manipulate md5 fingerprints
+ *      along with this program. If not, see
+ *      <http://www.gnu.org/licenses/>.
  *
  * Derived from code marked
  *      derived from RSADSI MD5 Message-Digest Algorithm
  *      Copyright (C) 1991-2, RSA Data Security, Inc. Created 1991.
- *      All rights reserved.
  *
  *      License to copy and use this software is granted provided that it
  *      is identified as the "RSA Data Security, Inc. MD5 Message-Digest
@@ -449,6 +445,11 @@ md5_sum(fingerprint_ty *p, char *obuf, size_t obuf_len)
         cp += strlen(cp);
     }
     *cp = 0;
+
+#ifdef DEBUG
+    /* silence gcc warning */
+    (void)trace_pretest_result;
+#endif
 }
 
 
