@@ -1,11 +1,10 @@
 /*
  *      cook - file construction tool
- *      Copyright (C) 1999, 2006, 2007 Peter Miller;
- *      All rights reserved.
+ *      Copyright (C) 1999, 2006-2009 Peter Miller
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
- *      the Free Software Foundation; either version 2 of the License, or
+ *      the Free Software Foundation; either version 3 of the License, or
  *      (at your option) any later version.
  *
  *      This program is distributed in the hope that it will be useful,
@@ -14,10 +13,8 @@
  *      GNU General Public License for more details.
  *
  *      You should have received a copy of the GNU General Public License
- *      along with this program; if not, write to the Free Software
- *      Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
- *
- * MANIFEST: functions for reading input and filtering out CR LF sequences
+ *      along with this program. If not, see
+ *      <http://www.gnu.org/licenses/>.
  */
 
 #include <common/input/crlf.h>
@@ -108,12 +105,12 @@ input_crlf(input_ty *fp, int delete_on_close)
     input_ty        *result;
     input_crlf_ty   *this;
 
-    trace(("input_crlf(fp = %08lX)\n{\n", (long)fp));
+    trace(("input_crlf(fp = %p)\n{\n", fp));
     result = input_new(&vtbl);
     this = (input_crlf_ty *) result;
     this->fp = fp;
     this->delete_on_close = delete_on_close;
-    trace(("return %08lX\n", (long)result));
+    trace(("return %p\n", result));
     trace(("}\n"));
     return result;
 }
