@@ -1,11 +1,10 @@
 /*
  *      cook - file construction tool
- *      Copyright (C) 1997, 2001, 2003, 2006, 2007 Peter Miller;
- *      All rights reserved.
+ *      Copyright (C) 1997, 2001, 2003, 2006-2009 Peter Miller
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
- *      the Free Software Foundation; either version 2 of the License, or
+ *      the Free Software Foundation; either version 3 of the License, or
  *      (at your option) any later version.
  *
  *      This program is distributed in the hope that it will be useful,
@@ -14,10 +13,8 @@
  *      GNU General Public License for more details.
  *
  *      You should have received a copy of the GNU General Public License
- *      along with this program; if not, write to the Free Software
- *      Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
- *
- * MANIFEST: functions to manipulate itabs
+ *      along with this program. If not, see
+ *      <http://www.gnu.org/licenses/>.
  */
 
 #include <common/itab.h>
@@ -60,7 +57,7 @@ itab_alloc(int size)
     itp->hash_table = mem_alloc(itp->hash_modulus * sizeof(itab_row_ty *));
     for (j = 0; j < itp->hash_modulus; ++j)
         itp->hash_table[j] = 0;
-    trace(("return %08lX;\n", (long)itp));
+    trace(("return %p;\n", itp));
     trace(("}\n"));
     return itp;
 }
@@ -83,7 +80,7 @@ itab_free(itab_ty *itp)
 {
     itab_key_ty     j;
 
-    trace(("itab_free(itp = %08lX)\n{\n", (long)itp));
+    trace(("itab_free(itp = %p)\n{\n", itp));
     for (j = 0; j < itp->hash_modulus; ++j)
     {
         itab_row_ty     **rpp;
@@ -213,7 +210,7 @@ itab_query(itab_ty *itp, itab_key_ty key)
     itab_row_ty     *p;
     void            *result;
 
-    trace(("itab_query(itp = %08lX, key = %ld)\n{\n", (long)itp, (long)key));
+    trace(("itab_query(itp = %p, key = %ld)\n{\n", itp, (long)key));
     result = 0;
     idx = key & itp->hash_mask;
     for (p = itp->hash_table[idx]; p; p = p->overflow)
@@ -224,7 +221,7 @@ itab_query(itab_ty *itp, itab_key_ty key)
             break;
         }
     }
-    trace(("return %08lX;\n", (long)result));
+    trace(("return %p;\n", result));
     trace(("}\n"));
     return result;
 }
@@ -251,8 +248,8 @@ itab_assign(itab_ty *itp, itab_key_ty key, void *data)
     itab_key_ty     idx;
     itab_row_ty     *p;
 
-    trace(("itab_assign(itp = %08lX, key = %ld, data = %08lX)\n{\n",
-        (long)itp, (long)key, (long)data));
+    trace(("itab_assign(itp = %p, key = %ld, data = %p)\n{\n", itp, (long)key,
+        data));
     idx = key & itp->hash_mask;
 
     for (p = itp->hash_table[idx]; p; p = p->overflow)
@@ -303,7 +300,7 @@ itab_delete(itab_ty *itp, itab_key_ty key)
     itab_key_ty     idx;
     itab_row_ty     **pp;
 
-    trace(("itab_delete(itp = %08lX, key = %ld)\n{\n", (long)itp, (long)key));
+    trace(("itab_delete(itp = %p, key = %ld)\n{\n", itp, (long)key));
     idx = key & itp->hash_mask;
 
     pp = &itp->hash_table[idx];
@@ -349,7 +346,7 @@ itab_walk(itab_ty *itp, void (*func)(itab_ty *, itab_key_ty, void *, void *),
     itab_key_ty     j;
     itab_row_ty     *rp;
 
-    trace(("itab_walk(itp = %08lX)\n{\n", (long)itp));
+    trace(("itab_walk(itp = %p)\n{\n", itp));
     for (j = 0; j < itp->hash_modulus; ++j)
         for (rp = itp->hash_table[j]; rp; rp = rp->overflow)
             func(itp, rp->key, rp->data, arg);
