@@ -1,11 +1,10 @@
 /*
  *      aegis - project change supervisor
- *      Copyright (C) 1999, 2001, 2006, 2007 Peter Miller;
- *      All rights reserved.
+ *      Copyright (C) 1999, 2001, 2006-2009 Peter Miller
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
- *      the Free Software Foundation; either version 2 of the License, or
+ *      the Free Software Foundation; either version 3 of the License, or
  *      (at your option) any later version.
  *
  *      This program is distributed in the hope that it will be useful,
@@ -14,10 +13,8 @@
  *      GNU General Public License for more details.
  *
  *      You should have received a copy of the GNU General Public License
- *      along with this program; if not, write to the Free Software
- *      Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
- *
- * MANIFEST: functions to manipulate quotes
+ *      along with this program. If not, see
+ *      <http://www.gnu.org/licenses/>.
  */
 
 #include <common/ac/ctype.h>
@@ -119,7 +116,7 @@ str_quote_shell(string_ty * s)
     if (!needs_quoting)
     {
         s = str_copy(s);
-        trace(("return %8.8lX;\n", (long)s));
+        trace(("return %p;\n", s));
         trace(("}\n"));
         return s;
     }
@@ -199,7 +196,7 @@ str_quote_shell(string_ty * s)
     /*
      * all done
      */
-    trace(("return %8.8lX;\n", (long)s));
+    trace(("return %p;\n", s));
     trace(("}\n"));
     return s;
 }
@@ -273,7 +270,7 @@ str_quote_cook(string_ty *s, int force)
     if (!needs_quoting)
     {
         s = str_copy(s);
-        trace(("return %8.8lX;\n", (long)s));
+        trace(("return %p;\n", s));
         trace(("}\n"));
         return s;
     }
@@ -345,7 +342,7 @@ str_quote_cook(string_ty *s, int force)
     /*
      * all done
      */
-    trace(("return %8.8lX;\n", (long)s));
+    trace(("return %p;\n", s));
     trace(("}\n"));
     return s;
 }
