@@ -1,11 +1,10 @@
 /*
  *      cook - file construction tool
- *      Copyright (C) 1997, 1998, 2006, 2007 Peter Miller;
- *      All rights reserved.
+ *      Copyright (C) 1997, 1998, 2006-2009 Peter Miller
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
- *      the Free Software Foundation; either version 2 of the License, or
+ *      the Free Software Foundation; either version 3 of the License, or
  *      (at your option) any later version.
  *
  *      This program is distributed in the hope that it will be useful,
@@ -14,10 +13,8 @@
  *      GNU General Public License for more details.
  *
  *      You should have received a copy of the GNU General Public License
- *      along with this program; if not, write to the Free Software
- *      Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
- *
- * MANIFEST: functions to manipulate rights
+ *      along with this program. If not, see
+ *      <http://www.gnu.org/licenses/>.
  */
 
 #include <common/str.h>
@@ -57,7 +54,7 @@ sub_right(sub_context_ty *scp, wstring_list_ty *arg)
         result =
             wstr_n_from_wc(ws->wstr_text + ws->wstr_length - n, (size_t) n);
     }
-    trace(("return %8.8lX;\n", (long)result));
+    trace(("return %p;\n", result));
     trace(("}\n"));
     return result;
 }
