@@ -1,11 +1,10 @@
 /*
  *      cook - file construction tool
- *      Copyright (C) 1990-1994, 1997, 2001, 2003, 2006, 2007 Peter Miller;
- *      All rights reserved.
+ *      Copyright (C) 1990-1994, 1997, 2001, 2003, 2006-2009 Peter Miller
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
- *      the Free Software Foundation; either version 2 of the License, or
+ *      the Free Software Foundation; either version 3 of the License, or
  *      (at your option) any later version.
  *
  *      This program is distributed in the hope that it will be useful,
@@ -14,10 +13,8 @@
  *      GNU General Public License for more details.
  *
  *      You should have received a copy of the GNU General Public License
- *      along with this program; if not, write to the Free Software
- *      Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
- *
- * MANIFEST: functions to manipulate symbol tables
+ *      along with this program. If not, see
+ *      <http://www.gnu.org/licenses/>.
  */
 
 #include <common/error.h> /* for debugging */
@@ -45,7 +42,7 @@ symtab_alloc(unsigned size)
         mem_alloc(stp->hash_modulus * sizeof(symtab_row_ty *));
     for (j = 0; j < stp->hash_modulus; ++j)
         stp->hash_table[j] = 0;
-    trace(("return %08lX;\n", (long)stp));
+    trace(("return %p;\n", stp));
     trace(("}\n"));
     return stp;
 }
@@ -56,7 +53,7 @@ symtab_free(symtab_ty *stp)
 {
     str_hash_ty     j;
 
-    trace(("symtab_free(stp = %08lX)\n{\n", (long)stp));
+    trace(("symtab_free(stp = %p)\n{\n", stp));
     for (j = 0; j < stp->hash_modulus; ++j)
     {
         symtab_row_ty   **rpp;
@@ -186,8 +183,7 @@ symtab_query(symtab_ty *stp, string_ty *key)
     symtab_row_ty   *p;
     void            *result;
 
-    trace(("symtab_query(stp = %08lX, key = \"%s\")\n{\n",
-        (long)stp, key->str_text));
+    trace(("symtab_query(stp = %p, key = \"%s\")\n{\n", stp, key->str_text));
     result = 0;
 
     idx = key->str_hash & stp->hash_mask;
@@ -200,7 +196,7 @@ symtab_query(symtab_ty *stp, string_ty *key)
         }
     }
 
-    trace(("return %08lX;\n", (long)result));
+    trace(("return %p;\n", result));
     trace(("}\n"));
     return result;
 }
@@ -213,8 +209,8 @@ symtab_query_fuzzy_inner(symtab_ty *stp, string_ty *key, double *best_weight,
     str_hash_ty     idx;
     symtab_row_ty   *p;
 
-    trace(("symtab_query_fuzzy_inner(stp = %08lX, key = \"%s\")\n{\n",
-        (long)stp, key->str_text));
+    trace(("symtab_query_fuzzy_inner(stp = %p, key = \"%s\")\n{\n", stp,
+        key->str_text));
 
     for (idx = 0; idx < stp->hash_modulus; ++idx)
     {
@@ -242,8 +238,7 @@ symtab_query_fuzzy(symtab_ty *stp, string_ty *key, string_ty **key_used)
     void            *best_result;
     string_ty       *best_key;
 
-    trace(("symtab_query(stp = %08lX, key = \"%s\")\n{\n",
-        (long)stp, key->str_text));
+    trace(("symtab_query(stp = %p, key = \"%s\")\n{\n", stp, key->str_text));
     best_weight = 0.6;
     best_result = 0;
     best_key = 0;
@@ -252,7 +247,7 @@ symtab_query_fuzzy(symtab_ty *stp, string_ty *key, string_ty **key_used)
 
     if (key_used && best_key)
         *key_used = best_key;
-    trace(("return %08lX;\n", (long)best_result));
+    trace(("return %p;\n", best_result));
     trace(("}\n"));
     return best_result;
 }
@@ -286,7 +281,7 @@ symtab_query_fuzzyN(symtab_ty **stp_table, size_t stp_length, string_ty *key,
 
     if (key_used && best_key)
         *key_used = best_key;
-    trace(("return %08lX;\n", (long)best_result));
+    trace(("return %p;\n", best_result));
     trace(("}\n"));
     return best_result;
 }
@@ -313,8 +308,8 @@ symtab_assign(symtab_ty *stp, string_ty *key, void *data)
     str_hash_ty     idx;
     symtab_row_ty   *p;
 
-    trace(("symtab_assign(stp = %08lX, key = \"%s\", data = %08lX)\n{\n",
-        (long)stp, key->str_text, (long)data));
+    trace(("symtab_assign(stp = %p, key = \"%s\", data = %p)\n{\n", stp,
+        key->str_text, data));
     idx = key->str_hash & stp->hash_mask;
     for (p = stp->hash_table[idx]; p; p = p->overflow)
     {
@@ -366,8 +361,8 @@ symtab_assign_push(symtab_ty *stp, string_ty *key, void *data)
     str_hash_ty     idx;
     symtab_row_ty   *p;
 
-    trace(("symtab_assign_push(stp = %08lX, key = \"%s\", data = %08lX)\n{\n",
-        (long)stp, key->str_text, (long)data));
+    trace(("symtab_assign_push(stp = %p, key = \"%s\", data = %p)\n{\n", stp,
+        key->str_text, data));
     idx = key->str_hash & stp->hash_mask;
 
     p = mem_alloc(sizeof(symtab_row_ty));
@@ -404,8 +399,7 @@ symtab_delete(symtab_ty *stp, string_ty *key)
     str_hash_ty     idx;
     symtab_row_ty   **pp;
 
-    trace(("symtab_delete(stp = %08lX, key = \"%s\")\n{\n",
-        (long)stp, key->str_text));
+    trace(("symtab_delete(stp = %p, key = \"%s\")\n{\n", stp, key->str_text));
     idx = key->str_hash & stp->hash_mask;
 
     pp = &stp->hash_table[idx];
@@ -461,12 +455,7 @@ symtab_dump(symtab_ty *stp, char *caption)
     {
         for (p = stp->hash_table[j]; p; p = p->overflow)
         {
-            error_raw
-            (
-                "key = \"%s\", data = %08lX",
-                p->key->str_text,
-                (long)p->data
-            );
+            error_raw("key = \"%s\", data = %p", p->key->str_text, p->data);
         }
     }
     error_raw("}");
@@ -482,7 +471,7 @@ symtab_walk(symtab_ty *stp, void (*func)(symtab_ty *, string_ty *, void *,
     str_hash_ty     j;
     symtab_row_ty   *rp;
 
-    trace(("symtab_walk(stp = %08lX)\n{\n", (long)stp));
+    trace(("symtab_walk(stp = %p)\n{\n", stp));
     for (j = 0; j < stp->hash_modulus; ++j)
         for (rp = stp->hash_table[j]; rp; rp = rp->overflow)
             func(stp, rp->key, rp->data, arg);
