@@ -1,11 +1,10 @@
 /*
  *      cook - file construction tool
- *      Copyright (C) 2007 Peter Miller;
- *      All rights reserved.
+ *      Copyright (C) 2007, 2008 Peter Miller
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
- *      the Free Software Foundation; either version 2 of the License, or
+ *      the Free Software Foundation; either version 3 of the License, or
  *      (at your option) any later version.
  *
  *      This program is distributed in the hope that it will be useful,
@@ -14,16 +13,14 @@
  *      GNU General Public License for more details.
  *
  *      You should have received a copy of the GNU General Public License
- *      along with this program; if not, write to the Free Software
- *      Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
- *
- * MANIFEST: interface definition for ts.c
+ *      along with this program. If not, see
+ *      <http://www.gnu.org/licenses/>.
  */
 
 #ifndef COMMON_TS_H
 #define COMMON_TS_H
 
-#include <common/main.h>
+#include <common/ac/time.h>
 
 time_t ts_granularity(void);
 
