@@ -1,11 +1,10 @@
 /*
  *      cook - file construction tool
- *      Copyright (C) 1997, 1999, 2001, 2006, 2007 Peter Miller;
- *      All rights reserved.
+ *      Copyright (C) 1997, 1999, 2001, 2006-2009 Peter Miller
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
- *      the Free Software Foundation; either version 2 of the License, or
+ *      the Free Software Foundation; either version 3 of the License, or
  *      (at your option) any later version.
  *
  *      This program is distributed in the hope that it will be useful,
@@ -14,12 +13,10 @@
  *      GNU General Public License for more details.
  *
  *      You should have received a copy of the GNU General Public License
- *      along with this program; if not, write to the Free Software
- *      Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
+ *      along with this program. If not, see
+ *      <http://www.gnu.org/licenses/>.
  *
  *
- * MANIFEST: wide string manipulation functions
- *
  * A literal pool is maintained.  Each string has a reference count.  The
  * string stays in the literal pool for as long as it has a positive
  * reference count.  To determine if a string is already in the literal pool,
@@ -301,7 +298,10 @@ wstr_n_from_c(const char *s, size_t length)
     /*
      * Reset the mbtowc internal state.
      */
-    mbtowc((wchar_t *) 0, (char *)0, 0);
+    if (mbtowc((wchar_t *) 0, (char *)0, 0) == -1)
+    {
+        assert(!"assume success");
+    }
 
     /*
      * scan the string and extract the wide characters
@@ -345,7 +345,10 @@ wstr_n_from_c(const char *s, size_t length)
              * be "error" or broken, or otherwise useless.
              * Reset it so that we can keep going.
              */
-            mbtowc((wchar_t *) 0, (char *)0, 0);
+            if (mbtowc((wchar_t *) 0, (char *)0, 0) == -1)
+            {
+                assert(!"assume success");
+            }
         }
         else
         {
@@ -424,7 +427,10 @@ wstr_to_mbs(wstring_ty *s, char **result_p, size_t *result_length_p)
     /*
      * The wctomb function has internal state.  It needs to be reset.
      */
-    wctomb((char *)0, (wchar_t) 0);
+    if (wctomb((char *)0, (wchar_t) 0) == -1)
+    {
+        assert(!"assume success");
+    }
 
     ip = s->wstr_text;
     remainder = s->wstr_length;
@@ -448,7 +454,10 @@ wstr_to_mbs(wstring_ty *s, char **result_p, size_t *result_length_p)
              * be "error" or broken, or otherwise useless.
              * Reset it so that we can keep going.
              */
-            wctomb((char *)0, (wchar_t) 0);
+            if (wctomb((char *)0, (wchar_t) 0) == -1)
+            {
+                assert(!"assume success");
+            }
         }
         else
         {
