@@ -1,10 +1,10 @@
 /*
  *      cook - file construction tool
- *      Copyright (C) 1993-2007 Peter Miller
+ *      Copyright (C) 1993-2008 Peter Miller
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
- *      the Free Software Foundation; either version 2 of the License, or
+ *      the Free Software Foundation; either version 3 of the License, or
  *      (at your option) any later version.
  *
  *      This program is distributed in the hope that it will be useful,
@@ -13,10 +13,8 @@
  *      GNU General Public License for more details.
  *
  *      You should have received a copy of the GNU General Public License
- *      along with this program; if not, write to the Free Software
- *      Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
- *
- * MANIFEST: functions to access the builtin functions
+ *      along with this program. If not, see
+ *      <http://www.gnu.org/licenses/>.
  *
  * The builtin functions all append their results to the supplied
  * `result' word list.  The first word of the `args' word list
@@ -78,6 +76,7 @@
 #include <cook/builtin/stringset.h>
 #include <cook/builtin/strip.h>
 #include <cook/builtin/stripdot.h>
+#include <cook/builtin/strlen.h>
 #include <cook/builtin/subst.h>
 #include <cook/builtin/substr.h>
 #include <cook/builtin/suffix.h>
@@ -174,6 +173,7 @@ static builtin_ty *func[] = {
     &builtin_stringset,
     &builtin_strip,
     &builtin_stripdot,
+    &builtin_strlen,
     &builtin_subst,
     &builtin_substitute,
     &builtin_substr,
