@@ -1,11 +1,10 @@
 /*
  *      cook - file construction tool
- *      Copyright (C) 1993, 1994, 1996-1999, 2001, 2006, 2007 Peter Miller;
- *      All rights reserved.
+ *      Copyright (C) 1993, 1994, 1996-1999, 2001, 2006-2009 Peter Miller
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
- *      the Free Software Foundation; either version 2 of the License, or
+ *      the Free Software Foundation; either version 3 of the License, or
  *      (at your option) any later version.
  *
  *      This program is distributed in the hope that it will be useful,
@@ -14,10 +13,8 @@
  *      GNU General Public License for more details.
  *
  *      You should have received a copy of the GNU General Public License
- *      along with this program; if not, write to the Free Software
- *      Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
- *
- * MANIFEST: functions to perform shell-style file pattern matching
+ *      along with this program. If not, see
+ *      <http://www.gnu.org/licenses/>.
  */
 
 #include <common/ac/errno.h>
@@ -84,7 +81,7 @@ globber(char *formal, const expr_position_ty * pp)
     int             retval;
     sub_context_ty  *scp;
 
-    trace(("globber(formal = %8.8lX)\n{\n", formal));
+    trace(("globber(formal = %p)\n{\n", formal));
     trace_string(formal);
     retval = 0;
     gmatch_error_handler(error_handler, (void *)pp);
@@ -104,7 +101,8 @@ globber(char *formal, const expr_position_ty * pp)
             size_t          n;
 
             /* nothing special */
-            trace(("ordinary = \"%.*s\";\n", formal_end - formal, formal));
+            trace(("ordinary = \"%.*s\";\n",
+                (int)(formal_end - formal), formal));
             for (cp = formal; cp < formal_end; ++cp)
                 sa_char(&temp, *cp);
             n = sa_mark(&temp);
@@ -158,7 +156,7 @@ globber(char *formal, const expr_position_ty * pp)
             struct dirent   *dep;
 
             /* need to expand wild characters */
-            trace(("expand = \"%.*s\";\n", formal_end - formal, formal));
+            trace(("expand = \"%.*s\";\n", (int)(formal_end - formal), formal));
             n = sa_mark(&temp);
             sa_char(&temp, 0);
             dp = opendir(n ? temp.sa_buf : ".");
@@ -287,7 +285,7 @@ interpret(string_list_ty *result, const string_list_ty *args,
     size_t          start;
     int             retval;
 
-    trace(("glob(result = %08X, args = %08X)\n{\n", result, args));
+    trace(("glob(result = %p, args = %p)\n{\n", result, args));
     (void)ocp;
     retval = 0;
     where = result;
