@@ -1,11 +1,10 @@
 /*
  *      cook - file construction tool
- *      Copyright (C) 1996-1999, 2003, 2006, 2007 Peter Miller;
- *      All rights reserved.
+ *      Copyright (C) 1996-1999, 2003, 2006-2009 Peter Miller
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
- *      the Free Software Foundation; either version 2 of the License, or
+ *      the Free Software Foundation; either version 3 of the License, or
  *      (at your option) any later version.
  *
  *      This program is distributed in the hope that it will be useful,
@@ -14,10 +13,8 @@
  *      GNU General Public License for more details.
  *
  *      You should have received a copy of the GNU General Public License
- *      along with this program; if not, write to the Free Software
- *      Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
- *
- * MANIFEST: functions to implement the builtin options function
+ *      along with this program. If not, see
+ *      <http://www.gnu.org/licenses/>.
  *
  *
  * If you are going to add a new recipe flag (set by the "set" statement,
@@ -38,7 +35,7 @@
  *     to define the RF_ values (RF stands for Recipe Flag)
  * cook/flag.c
  *     to define the RF_ names
- * langu.flags.so
+ * lib/en/user-guide/langu.flags.so
  *     to document the recipe flag
  *
  * If you choose to make it a command line option,
@@ -74,9 +71,13 @@ static table_ty table[] =
 {
     { OPTION_ACTION, "-action", "-noaction" },
     { OPTION_CASCADE, "-cascade", "-nocascade" },
+    { OPTION_CTIME, "-ctime", "-no-ctime" },
     { OPTION_ERROK, "-errok", "-noerrok" },
     { OPTION_FINGERPRINT, "-fingerprint", "-nofingerprint" },
     { OPTION_FORCE, "-force", "-noforce" },
+    { OPTION_INCLUDE_COOKED, "-include-cooked", "-no-include-cooked" },
+    { OPTION_INCLUDE_COOKED_WARNING, "-include-cooked-warning",
+        "-no-include-cooked-warning" },
     { OPTION_METER, "-meter", "-nometer" },
     { OPTION_PERSEVERE, "-continue", "-nocontinue" },
     { OPTION_PRECIOUS, "-precious", "-noprecious" },
@@ -86,10 +87,10 @@ static table_ty table[] =
     { OPTION_STAR, "-star", "-nostar" },
     { OPTION_STRIP_DOT, "-stripdot", "-nostripdot" },
     { OPTION_SYMLINK_INGREDIENTS, "-symlink-ingredi", "-no-symlink-ingredi" },
+    { OPTION_TELL_POSITION, "-tellposition", "-notellposition" },
     { OPTION_TERMINAL, "-terminal", "-noterminal" },
     { OPTION_TOUCH, "-touch", "-notouch" },
     { OPTION_UPDATE, "-timeadjust", "-notimeadjust" },
-    { OPTION_TELL_POSITION, "-tellposition", "-notellposition" },
 };
 
 
