@@ -1,11 +1,10 @@
 /*
  *      cook - file construction tool
- *      Copyright (C) 1999, 2001, 2004, 2006, 2007 Peter Miller;
- *      All rights reserved.
+ *      Copyright (C) 1999, 2001, 2004, 2006-2009 Peter Miller
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
- *      the Free Software Foundation; either version 2 of the License, or
+ *      the Free Software Foundation; either version 3 of the License, or
  *      (at your option) any later version.
  *
  *      This program is distributed in the hope that it will be useful,
@@ -14,10 +13,8 @@
  *      GNU General Public License for more details.
  *
  *      You should have received a copy of the GNU General Public License
- *      along with this program; if not, write to the Free Software
- *      Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
- *
- * MANIFEST: functions to implement the write builtin function
+ *      along with this program. If not, see
+ *      <http://www.gnu.org/licenses/>.
  */
 
 #include <common/ac/stdio.h>
@@ -58,7 +55,7 @@ interpret(string_list_ty *result, const string_list_ty *args,
     size_t          j;
     int             retval;
 
-    trace(("write::interpret(result = %08X, args = %08X)\n{\n", result, args));
+    trace(("write::interpret(result = %p, args = %p)\n{\n", result, args));
     (void)result;
     (void)ocp;
     retval = 0;
@@ -164,7 +161,7 @@ script(string_list_ty *result, const string_list_ty *args,
     static int      the_end_n;
     string_ty       *s;
 
-    trace(("write::script(result = %08X, args = %08X)\n{\n", result, args));
+    trace(("write::script(result = %p, args = %p)\n{\n", result, args));
     (void)result;
     (void)ocp;
     retval = 0;
