@@ -1,11 +1,10 @@
 /*
  *      cook - file construction tool
- *      Copyright (C) 1990-1997, 2006, 2007 Peter Miller
- *      All rights reserved.
+ *      Copyright (C) 1990-1997, 2006-2009 Peter Miller
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
- *      the Free Software Foundation; either version 2 of the License, or
+ *      the Free Software Foundation; either version 3 of the License, or
  *      (at your option) any later version.
  *
  *      This program is distributed in the hope that it will be useful,
@@ -14,10 +13,8 @@
  *      GNU General Public License for more details.
  *
  *      You should have received a copy of the GNU General Public License
- *      along with this program; if not, write to the Free Software
- *      Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
- *
- * MANIFEST: functions to manipulate expression trees
+ *      along with this program. If not, see
+ *      <http://www.gnu.org/licenses/>.
  *
  * This file contains the functions for manipulating expression
  * trees; building, interpreting and freeing them.
@@ -75,7 +72,7 @@ expr_private_new(expr_method_ty *mp)
     ep->method = mp;
     ep->e_references = 1;
     expr_position_constructor(&ep->e_position, lex_cur_file(), lex_cur_line());
-    trace(("return %08lX;\n", ep));
+    trace(("return %p;\n", ep));
     trace(("}\n"));
     return ep;
 }
@@ -103,9 +100,9 @@ expr_private_new(expr_method_ty *mp)
 expr_ty *
 expr_copy(expr_ty *ep)
 {
-    trace(("expr_copy(ep = %08X)\n{\n", ep));
+    trace(("expr_copy(ep = %p)\n{\n", ep));
     ep->e_references++;
-    trace(("return %08lX;\n", ep));
+    trace(("return %p;\n", ep));
     trace(("}\n"));
     return ep;
 }
@@ -129,7 +126,7 @@ expr_copy(expr_ty *ep)
 void
 expr_delete(expr_ty *ep)
 {
-    trace(("expr_delete(ep = %08X)\n{\n", ep));
+    trace(("expr_delete(ep = %p)\n{\n", ep));
     assert(ep);
     ep->e_references--;
     if (ep->e_references <= 0)
@@ -168,14 +165,14 @@ expr_evaluate(const expr_ty *ep, const match_ty *mp)
     opcode_list_ty  *olp;
     string_list_ty  *result;
 
-    trace(("expr_evaluate(ep = %08lX)\n{\n", (long)ep));
+    trace(("expr_evaluate(ep = %p)\n{\n", ep));
     assert(ep);
     olp = opcode_list_new();
     opcode_list_append(olp, opcode_push_new());
     expr_code_generate(ep, olp);
     result = opcode_list_run(olp, mp);
     opcode_list_delete(olp);
-    trace(("return %08lX;\n", result));
+    trace(("return %p;\n", result));
     trace(("}\n"));
     return result;
 }
@@ -210,7 +207,7 @@ expr_eval_condition(const expr_ty *ep, const match_ty *mp)
     opcode_list_ty  *olp;
     int             result;
 
-    trace(("expr_eval_condition(ep = %08lX)\n{\n", (long)ep));
+    trace(("expr_eval_condition(ep = %p)\n{\n", ep));
     assert(ep);
     olp = opcode_list_new();
     opcode_list_append(olp, opcode_push_new());
