@@ -1,11 +1,10 @@
 /*
  *      cook - file construction tool
- *      Copyright (C) 1999, 2006, 2007 Peter Miller;
- *      All rights reserved.
+ *      Copyright (C) 1999, 2006-2009 Peter Miller
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
- *      the Free Software Foundation; either version 2 of the License, or
+ *      the Free Software Foundation; either version 3 of the License, or
  *      (at your option) any later version.
  *
  *      This program is distributed in the hope that it will be useful,
@@ -14,10 +13,8 @@
  *      GNU General Public License for more details.
  *
  *      You should have received a copy of the GNU General Public License
- *      along with this program; if not, write to the Free Software
- *      Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
- *
- * MANIFEST: functions to manipulate fingerprints
+ *      along with this program. If not, see
+ *      <http://www.gnu.org/licenses/>.
  */
 
 #include <cook/fingerprint.h>
@@ -56,7 +53,7 @@ fp_search(string_ty *path)
         trace(("}\n"));
         return 0;
     }
-    trace(("return %08lX;\n", (long)&p->value));
+    trace(("return %p;\n", &p->value));
     trace(("}\n"));
     return &p->value;
 }
@@ -82,8 +79,7 @@ fp_assign(string_ty *path, fp_value_ty *fp)
 {
     fp_record_ty    *p;
 
-    trace(("fp_assign(path = \"%s\", fp = %08lX)\n{\n",
-            path->str_text, (long)fp));
+    trace(("fp_assign(path = \"%s\", fp = %p)\n{\n", path->str_text, fp));
     p = fp_find_record(path);
     fp_record_update(p, fp);
     trace(("}\n"));
