@@ -1,11 +1,10 @@
 /*
  *      cook - file construction tool
- *      Copyright (C) 1999, 2001, 2002, 2006, 2007 Peter Miller;
- *      All rights reserved.
+ *      Copyright (C) 1999, 2001, 2002, 2006-2009 Peter Miller
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
- *      the Free Software Foundation; either version 2 of the License, or
+ *      the Free Software Foundation; either version 3 of the License, or
  *      (at your option) any later version.
  *
  *      This program is distributed in the hope that it will be useful,
@@ -14,10 +13,8 @@
  *      GNU General Public License for more details.
  *
  *      You should have received a copy of the GNU General Public License
- *      along with this program; if not, write to the Free Software
- *      Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
- *
- * MANIFEST: functions to manipulate finds
+ *      along with this program. If not, see
+ *      <http://www.gnu.org/licenses/>.
  */
 
 #include <common/ac/string.h>
@@ -131,7 +128,7 @@ fp_find_subdir(string_ty *dirname, int ok_to_read)
         fp_subdir_read(sdp);
     }
 
-    trace(("return %08lX;\n", (long)sdp));
+    trace(("return %p;\n", sdp));
     trace(("}\n"));
     return sdp;
 }
@@ -216,7 +213,7 @@ fp_find_record(string_ty *path_a)
     }
 
     str_free(path_r);
-    trace(("return %08lX;\n", (long)p));
+    trace(("return %p;\n", p));
     trace(("}\n"));
     return p;
 }
@@ -245,8 +242,8 @@ fp_find_update(fp_subdir_ty *sdp, string_ty *file, fp_value_ty *fp)
     /*
      * build the actual filename
      */
-    trace(("fp_find_update(sdp = %08lX, file = \"%s\", fp = %08lX)\n{\n",
-            (long)sdp, file->str_text, (long)fp));
+    trace(("fp_find_update(sdp = %p, file = \"%s\", fp = %p)\n{\n", sdp,
+        file->str_text, fp));
     filename = os_path_cat(sdp->path, file);
 
     /*
