@@ -1,11 +1,10 @@
 /*
  *      cook - file construction tool
- *      Copyright (C) 1999, 2001, 2006, 2007 Peter Miller;
- *      All rights reserved.
+ *      Copyright (C) 1999, 2001, 2006-2009 Peter Miller
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
- *      the Free Software Foundation; either version 2 of the License, or
+ *      the Free Software Foundation; either version 3 of the License, or
  *      (at your option) any later version.
  *
  *      This program is distributed in the hope that it will be useful,
@@ -14,10 +13,8 @@
  *      GNU General Public License for more details.
  *
  *      You should have received a copy of the GNU General Public License
- *      along with this program; if not, write to the Free Software
- *      Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
- *
- * MANIFEST: functions to manipulate subdirs
+ *      along with this program. If not, see
+ *      <http://www.gnu.org/licenses/>.
  */
 
 #include <common/ac/errno.h>
@@ -91,7 +88,7 @@ fp_subdir_new(string_ty *path)
     this->dirty = 0;
     this->cache_in_dot = 0;
     this->need_to_read = 1;
-    trace(("return %08lX;\n", (long)this));
+    trace(("return %p;\n", this));
     trace(("}\n"));
     return this;
 }
@@ -112,7 +109,7 @@ fp_subdir_new(string_ty *path)
 void
 fp_subdir_delete(fp_subdir_ty *this)
 {
-    trace(("fp_subdir_delete(this = %08lX)\n{\n", (long)this));
+    trace(("fp_subdir_delete(this = %p)\n{\n", this));
     str_free(this->path);
     this->path = 0;
     symtab_free(this->stp);
@@ -143,7 +140,7 @@ fp_subdir_read(fp_subdir_ty *this)
         return;
     this->need_to_read = 0;
 
-    trace(("fp_subdir_read(this = %08lX)\n{\n", (long)this));
+    trace(("fp_subdir_read(this = %p)\n{\n", this));
     fn = os_path_cat(this->path, fp_filename());
     fp_gram(this, fn);
     str_free(fn);
@@ -171,8 +168,8 @@ walk(symtab_ty *sp, string_ty *key, void *p, void *arg)
     fp_record_ty    *data;
     FILE            *fp;
 
-    trace(("walk(sp = %08lX, key = \"%s\", p = %08lX, arg = %08lX)\n{\n",
-            (long)sp, key->str_text, (long)p, (long)arg));
+    trace(("walk(sp = %p, key = \"%s\", p = %p, arg = %p)\n{\n", sp,
+        key->str_text, p, arg));
     (void)sp;
     data = p;
     fp = arg;
@@ -207,7 +204,7 @@ fp_subdir_write(fp_subdir_ty *this, int *need_to_write_dot)
     /*
      * If we aren't dirty, don't write us out
      */
-    trace(("fp_subdir_write(this = %08lX)\n{\n", (long)this));
+    trace(("fp_subdir_write(this = %p)\n{\n", this));
     if (!this->dirty)
     {
         trace(("not dirty\n"));
@@ -339,7 +336,7 @@ fp_subdir_tweak(fp_subdir_ty *this)
     /*
      * read the directory
      */
-    trace(("fp_subdir_update(this = %08lX)\n{\n", (long)this));
+    trace(("fp_subdir_update(this = %p)\n{\n", this));
     star_as_specified('*');
     dp = opendir(this->path->str_text);
     if (!dp)
