@@ -1,11 +1,10 @@
 /*
  *      cook - file construction tool
- *      Copyright (C) 1997-1999, 2001-2003, 2006 Peter Miller;
- *      All rights reserved.
+ *      Copyright (C) 1997-1999, 2001-2003, 2006-2009 Peter Miller
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
- *      the Free Software Foundation; either version 2 of the License, or
+ *      the Free Software Foundation; either version 3 of the License, or
  *      (at your option) any later version.
  *
  *      This program is distributed in the hope that it will be useful,
@@ -14,10 +13,8 @@
  *      GNU General Public License for more details.
  *
  *      You should have received a copy of the GNU General Public License
- *      along with this program; if not, write to the Free Software
- *      Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
- *
- * MANIFEST: functions to build dependency graphs
+ *      along with this program. If not, see
+ *      <http://www.gnu.org/licenses/>.
  */
 
 #include <common/error.h>
@@ -155,8 +152,8 @@ graph_check_ingredients(graph_ty *gp, recipe_ty *rp,
     /*
      * be optimistic, assume success
      */
-    trace(("graph_check_ingredients(gp = %8.8lX, rp = %8.8lX, "
-        "preference = %d)\n{\n", (long)gp, (long)rp, (int)preference));
+    trace(("graph_check_ingredients(gp = %p, rp = %p, preference = %d)\n{\n",
+        gp, rp, (int)preference));
     ocp = 0;
     cascade_list_constructor(&cascade);
     if (rp->inhibit)
@@ -830,8 +827,8 @@ graph_check_recipe(graph_ty *gp, recipe_ty *rp,
     size_t          k;
     opcode_context_ty *ocp;
 
-    trace(("graph_check_recipe(gp = %8.8lX, rp = %8.8lX, "
-        "preference = %d)\n{\n", (long)gp, (long)rp, (int)preference));
+    trace(("graph_check_recipe(gp = %p, rp = %p, preference = %d)\n{\n", gp,
+        rp, (int)preference));
     ocp = 0;
     status =
         graph_check_ingredients
@@ -979,11 +976,11 @@ graph_check_recipe(graph_ty *gp, recipe_ty *rp,
                 {
                     error_raw
                     (
-                        "%s: %d: file pair \"%S: %S\" missing",
+                        "%s: %d: file pair \"%s: %s\" missing",
                         __FILE__,
                         __LINE__,
-                        target1,
-                        ingredient
+                        (target1 ? target1->str_text : ""),
+                        (ingredient ? ingredient->str_text : "")
                     );
                     ok = 0;
                 }
@@ -1105,9 +1102,9 @@ graph_build_file(graph_ty *gp, string_ty *target,
      */
     graph_file_list_nrc_ty common_ingredients_gfl;
 
-    trace(("graph_build_file(gp = %8.8lX, target = %08lX, preference = %d, "
-        "result = %8.8lX, imp=%d)\n{\n", (long)gp, (long)target,
-        (int)preference, (long)result, implicit_allowed));
+    trace(("graph_build_file(gp = %p, target = %p, preference = %d, "
+        "result = %p, imp = %d)\n{\n", gp, target, (int)preference, result,
+        implicit_allowed));
     result->status = graph_build_status_error;
     result->gfp = 0;
     gfp = 0;
@@ -2064,8 +2061,8 @@ graph_build_file(graph_ty *gp, string_ty *target,
     str_free(target);
     assert((result->status == graph_build_status_success) ==
         (result->gfp != 0));
-    trace(("return { %s, %8.8lX};\n", graph_build_status_name(result->status),
-        (long)result->gfp));
+    trace(("return { %s, %p };\n", graph_build_status_name(result->status),
+        result->gfp));
     trace(("}\n"));
 }
 
