@@ -1,11 +1,10 @@
 /*
  *      cook - file construction tool
- *      Copyright (C) 1997, 2006, 2007 Peter Miller;
- *      All rights reserved.
+ *      Copyright (C) 1997, 2006-2009 Peter Miller
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
- *      the Free Software Foundation; either version 2 of the License, or
+ *      the Free Software Foundation; either version 3 of the License, or
  *      (at your option) any later version.
  *
  *      This program is distributed in the hope that it will be useful,
@@ -14,10 +13,8 @@
  *      GNU General Public License for more details.
  *
  *      You should have received a copy of the GNU General Public License
- *      along with this program; if not, write to the Free Software
- *      Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
- *
- * MANIFEST: functions to manipulate graph files
+ *      along with this program. If not, see
+ *      <http://www.gnu.org/licenses/>.
  */
 
 #include <cook/graph/file.h>
@@ -60,7 +57,7 @@ graph_file_new(string_ty *fn)
     gfp->previous_backtrack = 0;
     gfp->previous_error = 0;
     gfp->primary_target = 0;
-    trace(("return %08lX;\n", (long)gfp));
+    trace(("return %p;\n", gfp));
     trace(("}\n"));
     return gfp;
 }
@@ -81,7 +78,7 @@ graph_file_new(string_ty *fn)
 void
 graph_file_delete(graph_file_ty *gfp)
 {
-    trace(("graph_file_delete(gfp = %08lX)\n{\n", gfp));
+    trace(("graph_file_delete(gfp = %p)\n{\n", gfp));
     assert(gfp);
     assert(gfp->reference_count > 0);
     gfp->reference_count--;
