@@ -1,11 +1,10 @@
 /*
  *      cook - file construction tool
- *      Copyright (C) 1997, 1999, 2000, 2006, 2007 Peter Miller;
- *      All rights reserved.
+ *      Copyright (C) 1997, 1999, 2000, 2006-2009 Peter Miller
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
- *      the Free Software Foundation; either version 2 of the License, or
+ *      the Free Software Foundation; either version 3 of the License, or
  *      (at your option) any later version.
  *
  *      This program is distributed in the hope that it will be useful,
@@ -14,10 +13,8 @@
  *      GNU General Public License for more details.
  *
  *      You should have received a copy of the GNU General Public License
- *      along with this program; if not, write to the Free Software
- *      Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
- *
- * MANIFEST: functions to manipulate recipes
+ *      along with this program. If not, see
+ *      <http://www.gnu.org/licenses/>.
  */
 
 #include <cook/cook.h>
@@ -76,7 +73,7 @@ graph_recipe_new(recipe_ty *rp)
     grp->single_thread = 0;
     grp->host_binding = 0;
     grp->multi_forced = 0;
-    trace(("return %08lX;\n", (long)grp));
+    trace(("return %p;\n", grp));
     trace(("}\n"));
     return grp;
 }
@@ -97,7 +94,7 @@ graph_recipe_new(recipe_ty *rp)
 void
 graph_recipe_delete(graph_recipe_ty *grp)
 {
-    trace(("graph_recipe_delete(grp = %08lX)\n{\n", (long)grp));
+    trace(("graph_recipe_delete(grp = %p)\n{\n", grp));
     assert(grp->reference_count > 0);
     grp->reference_count--;
     if (grp->reference_count > 0)
