@@ -1,11 +1,10 @@
 /*
  *      cook - file construction tool
- *      Copyright (C) 1997-1999, 2001, 2003, 2004, 2006, 2007 Peter Miller;
- *      All rights reserved.
+ *      Copyright (C) 1997-1999, 2001, 2003, 2004, 2006-2009 Peter Miller
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
- *      the Free Software Foundation; either version 2 of the License, or
+ *      the Free Software Foundation; either version 3 of the License, or
  *      (at your option) any later version.
  *
  *      This program is distributed in the hope that it will be useful,
@@ -14,10 +13,8 @@
  *      GNU General Public License for more details.
  *
  *      You should have received a copy of the GNU General Public License
- *      along with this program; if not, write to the Free Software
- *      Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
- *
- * MANIFEST: functions to walk a single graph recipe node
+ *      along with this program. If not, see
+ *      <http://www.gnu.org/licenses/>.
  */
 
 #include <common/ac/string.h>
@@ -111,11 +108,13 @@ host_binding_round_robin(opcode_context_ty *ocp, string_list_ty *slp)
 static string_ty *
 relevate(string_ty *from, string_ty *to)
 {
+    const char      *cp;
+
     if (from->str_text[0] == '/')
         return str_copy(from);
     if (to->str_text[0] == '/')
         return os_path_cat(os_curdir(), from);
-    const char *cp = to->str_text;
+    cp = to->str_text;
     from = str_copy(from);
     for (;;)
     {
@@ -180,7 +179,7 @@ graph_recipe_run(graph_recipe_ty *grp, graph_ty *gp)
     sub_context_ty  *scp;
     time_t          timestamp_granularity;
 
-    trace(("graph_recipe_run(grp = %08lX)\n{\n", (long)grp));
+    trace(("graph_recipe_run(grp = %p)\n{\n", grp));
     status = graph_walk_status_uptodate;
     timestamp_granularity = ts_granularity();
 
@@ -474,7 +473,7 @@ graph_recipe_run(graph_recipe_ty *grp, graph_ty *gp)
         target_depth = 0;
     }
     trace(("forced = %d;\n", forced));
-    trace(("target_depth = %d;\n", target_depth));
+    trace(("target_depth = %ld;\n", target_depth));
     trace(("target_age = %ld;\n", (long)target_age));
 
     /*
@@ -491,7 +490,7 @@ graph_recipe_run(graph_recipe_ty *grp, graph_ty *gp)
 
         gftp2 = grp->input->item + j;
         gfp2 = gftp2->file;
-        trace(("%d/%d \"%s\"\n", j, grp->input->nfiles,
+        trace(("%d/%d \"%s\"\n", (int)j, (int)(grp->input->nfiles),
                 gfp2->filename->str_text));
         depth2 = 32767;
         age2 =
@@ -638,7 +637,7 @@ graph_recipe_run(graph_recipe_ty *grp, graph_ty *gp)
          */
         if (depth2 < target_depth && !phony)
         {
-            trace(("depth2 = %d;\n", depth2));
+            trace(("depth2 = %ld;\n", depth2));
             if (!forced)
             {
                 if (show_reasoning)
@@ -779,9 +778,10 @@ graph_recipe_run(graph_recipe_ty *grp, graph_ty *gp)
                     if (from && !str_equal(from, to))
                     {
                         string_ty       *from2;
+                        int             echo;
 
                         from2 = relevate(from, to);
-                        int echo = !option_test(OPTION_SILENT);
+                        echo = !option_test(OPTION_SILENT);
                         os_symlink(from2, to, echo);
                         str_free(from2);
                     }
