@@ -1,11 +1,10 @@
 /*
  *      cook - file construction tool
- *      Copyright (C) 1997, 1999, 2001, 2003, 2006, 2007 Peter Miller;
- *      All rights reserved.
+ *      Copyright (C) 1997, 1999, 2001, 2003, 2006-2009 Peter Miller
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
- *      the Free Software Foundation; either version 2 of the License, or
+ *      the Free Software Foundation; either version 3 of the License, or
  *      (at your option) any later version.
  *
  *      This program is distributed in the hope that it will be useful,
@@ -14,10 +13,8 @@
  *      GNU General Public License for more details.
  *
  *      You should have received a copy of the GNU General Public License
- *      along with this program; if not, write to the Free Software
- *      Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
- *
- * MANIFEST: functions to print dependency graphs as a shell script
+ *      along with this program. If not, see
+ *      <http://www.gnu.org/licenses/>.
  */
 
 #include <common/ac/stdio.h>
@@ -68,7 +65,7 @@ graph_recipe_script(graph_recipe_ty *grp, struct graph_ty *gp)
     int             forced;
     long            file_pos = 0;
 
-    trace(("graph_recipe_script(grp = %08lX)\n{\n", (long)grp));
+    trace(("graph_recipe_script(grp = %p)\n{\n", grp));
     status = graph_walk_status_done;
 
     grp->ocp = opcode_context_new(0, grp->mp);
@@ -145,7 +142,7 @@ graph_recipe_script(graph_recipe_ty *grp, struct graph_ty *gp)
 
             js = str_quote_shell(grp->output->item[j].file->filename);
             if (j)
-                printf(" \\\n\t-o");
+                printf(" \\\n  -o");
             /* target does not exist */
             printf(" ! -e %s", js->str_text);
             for (k = 0; k < grp->input->nfiles; ++k)
@@ -179,7 +176,7 @@ graph_recipe_script(graph_recipe_ty *grp, struct graph_ty *gp)
                      * two files to have the same time
                      * stamp, and still be up-to-date.
                      */
-                    printf(" \\\n\t-o %s -nt %s", ingr->str_text, js->str_text);
+                    printf(" \\\n  -o %s -nt %s", ingr->str_text, js->str_text);
                     break;
 
                 case edge_type_strict:
@@ -190,7 +187,7 @@ graph_recipe_script(graph_recipe_ty *grp, struct graph_ty *gp)
                      * time stamps.
                      */
                     printf
-                        (" \\\n\t-o ! %s -nt %s", js->str_text, ingr->str_text);
+                        (" \\\n  -o ! %s -nt %s", js->str_text, ingr->str_text);
                     break;
                 }
                 str_free(ingr);
