@@ -1,10 +1,10 @@
 /*
  *      cook - file construction tool
- *      Copyright (C) 1993-2007 Peter Miller
+ *      Copyright (C) 1993-2007, 2009 Peter Miller
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
- *      the Free Software Foundation; either version 2 of the License, or
+ *      the Free Software Foundation; either version 3 of the License, or
  *      (at your option) any later version.
  *
  *      This program is distributed in the hope that it will be useful,
@@ -13,10 +13,8 @@
  *      GNU General Public License for more details.
  *
  *      You should have received a copy of the GNU General Public License
- *      along with this program; if not, write to the Free Software
- *      Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
- *
- * MANIFEST: functions to perform lexical analysis on cookbooks
+ *      along with this program. If not, see
+ *      <http://www.gnu.org/licenses/>.
  *
  * This file contains the lexical analyser for the cookbook parser.
  * A known bug is that it processes # control lines even within comments.
@@ -116,7 +114,7 @@ internal_token_name(internal_token_ty tok)
     case internal_token_file_boundary:
         return "internal_token_file_boundary";
     }
-    sprintf(buffer, "%d", tok);
+    snprintf(buffer, sizeof(buffer), "%d", tok);
     return buffer;
 }
 
@@ -286,7 +284,7 @@ lex_open(string_ty *logical, string_ty *physical)
 {
     lex_ty          *new;
 
-    trace(("lex_open(filename = %08lX)\n{\n", logical));
+    trace(("lex_open(filename = %p)\n{\n", logical));
     trace_string(logical->str_text);
     if (!physical)
         physical = logical;
@@ -553,7 +551,7 @@ meta_repn(meta_ty *val)
     char            buf2[20];
     char            buf3[10];
 
-    if (val->m_type >= 0 && val->m_type < SIZEOF(type))
+    if (val->m_type >= 0 && (size_t)val->m_type < SIZEOF(type))
         strendcpy(buf2, type[val->m_type], buf2 + sizeof(buf2));
     else
         snprintf(buf2, sizeof(buf2), "%d", val->m_type);
@@ -566,7 +564,7 @@ meta_repn(meta_ty *val)
             buf3[1] = 0;
         }
         else
-            sprintf(buf3, "\\%03o", (unsigned char)val->m_char);
+            snprintf(buf3, sizeof(buf3), "\\%03o", (unsigned char)val->m_char);
         break;
 
     case '\'':
@@ -612,7 +610,7 @@ meta_repn(meta_ty *val)
 static void
 meta(meta_ty *val)
 {
-    trace(("meta(val = %08lX)\n{\n", val));
+    trace(("meta(val = %p)\n{\n", val));
     assert(root);
     if (root->l_mback.m_type)
     {
@@ -1092,7 +1090,7 @@ lex_trace(char *s, ...)
         *cp = 0;
         trace_printf
         (
-            "%s: %d: %s\n",
+            "%s: %ld: %s\n",
             root->filename.logical->str_text,
             root->l_line,
             line
@@ -1115,9 +1113,9 @@ mode_repn(lex_mode_ty n)
     };
     static char     buffer[12];
 
-    if (n >= 0 && n < SIZEOF(name))
+    if ((size_t)n < SIZEOF(name))
         return name[n];
-    sprintf(buffer, "%d", n);
+    snprintf(buffer, sizeof(buffer), "%d", n);
     return buffer;
 }
 
@@ -1266,7 +1264,7 @@ tokenize(void)
             {
                 trace
                 ((
-                    "%s: %d: state %d, mode %s;\n",
+                    "%s: %ld: state %d, mode %s;\n",
                     root->filename.logical->str_text,
                     root->l_line,
                     state,
@@ -1506,8 +1504,8 @@ tokenize(void)
     ret:
     trace
     ((
-        "%S: %d: state %d, mode %s;\n",
-        root->filename.logical,
+        "%s: %ld: state %d, mode %s;\n",
+        root->filename.logical->str_text,
         root->l_line,
         state,
         mode_repn(mode)
