@@ -1,11 +1,10 @@
 /*
  *      cook - file construction tool
- *      Copyright (C) 1994-1999, 2001, 2003, 2004, 2006, 2007 Peter Miller;
- *      All rights reserved.
+ *      Copyright (C) 1994-1999, 2001, 2003, 2004, 2006-2008 Peter Miller
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
- *      the Free Software Foundation; either version 2 of the License, or
+ *      the Free Software Foundation; either version 3 of the License, or
  *      (at your option) any later version.
  *
  *      This program is distributed in the hope that it will be useful,
@@ -14,10 +13,8 @@
  *      GNU General Public License for more details.
  *
  *      You should have received a copy of the GNU General Public License
- *      along with this program; if not, write to the Free Software
- *      Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
- *
- * MANIFEST: operating system start point, and command line argument parsing
+ *      along with this program. If not, see
+ *      <http://www.gnu.org/licenses/>.
  *
  *
  * If you are going to add a new recipe flag (set by the "set" statement,
@@ -89,6 +86,8 @@ enum
     arglex_token_book_not,
     arglex_token_cascade,
     arglex_token_cascade_not,
+    arglex_token_ctime,
+    arglex_token_ctime_not,
     arglex_token_disassemble,
     arglex_token_disassemble_not,
     arglex_token_errok,
@@ -152,6 +151,8 @@ static arglex_table_ty argtab[] =
     { "-No_Book", (arglex_token_ty) arglex_token_book_not },
     { "-CAScade", (arglex_token_ty) arglex_token_cascade },
     { "-No_CAScade", (arglex_token_ty) arglex_token_cascade_not },
+    { "-CTime", (arglex_token_ty) arglex_token_ctime },
+    { "-No_CTime", (arglex_token_ty) arglex_token_ctime_not },
     { "-Continue", (arglex_token_ty) arglex_token_persevere },
     { "-No_Continue", (arglex_token_ty) arglex_token_persevere_not },
     { "-DISassemble", (arglex_token_ty) arglex_token_disassemble },
@@ -340,6 +341,14 @@ argparse(option_level_ty level)
             type = OPTION_CASCADE;
             goto normal_off;
 
+        case arglex_token_ctime:
+            type = OPTION_CTIME;
+            goto normal_on;
+
+        case arglex_token_ctime_not:
+            type = OPTION_CTIME;
+            goto normal_off;
+
         case arglex_token_disassemble:
             type = OPTION_DISASSEMBLE;
             goto normal_on;
