@@ -1,11 +1,10 @@
 /*
  *      cook - file construction tool
- *      Copyright (C) 1999, 2006, 2007 Peter Miller;
- *      All rights reserved.
+ *      Copyright (C) 1999, 2006-2009 Peter Miller
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
- *      the Free Software Foundation; either version 2 of the License, or
+ *      the Free Software Foundation; either version 3 of the License, or
  *      (at your option) any later version.
  *
  *      This program is distributed in the hope that it will be useful,
@@ -14,10 +13,8 @@
  *      GNU General Public License for more details.
  *
  *      You should have received a copy of the GNU General Public License
- *      along with this program; if not, write to the Free Software
- *      Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
- *
- * MANIFEST: functions to manipulate pattern matching stacks
+ *      along with this program. If not, see
+ *      <http://www.gnu.org/licenses/>.
  */
 
 #include <cook/match/stack.h>
@@ -45,7 +42,7 @@
 void
 match_stack_push(match_stack_ty *msp, const match_ty *field)
 {
-    trace(("match_stack_push(field = %08X)\n{\n", field));
+    trace(("match_stack_push(field = %p)\n{\n", field));
     if (msp->stack_depth >= msp->stack_depth_max)
     {
         size_t          nbytes;
@@ -117,7 +114,7 @@ match_stack_pop(match_stack_ty *msp)
     }
     else
         field = 0;
-    trace(("return %08X;\n", field));
+    trace(("return %p;\n", field));
     trace(("}\n"));
     return field;
 }
