@@ -1,11 +1,10 @@
 /*
  *      cook - file construction tool
- *      Copyright (C) 1997, 2006, 2007 Peter Miller;
- *      All rights reserved.
+ *      Copyright (C) 1997, 2006-2009 Peter Miller
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
- *      the Free Software Foundation; either version 2 of the License, or
+ *      the Free Software Foundation; either version 3 of the License, or
  *      (at your option) any later version.
  *
  *      This program is distributed in the hope that it will be useful,
@@ -14,10 +13,8 @@
  *      GNU General Public License for more details.
  *
  *      You should have received a copy of the GNU General Public License
- *      along with this program; if not, write to the Free Software
- *      Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
- *
- * MANIFEST: functions to manipulate opcodes
+ *      along with this program. If not, see
+ *      <http://www.gnu.org/licenses/>.
  */
 
 #include <common/ac/stdio.h>
@@ -42,7 +39,7 @@
 void
 opcode_delete(opcode_ty *op)
 {
-    trace(("opcode_delete(op = %08lX)\n{\n", (long)op));
+    trace(("opcode_delete(op = %p)\n{\n", op));
     assert(op);
     assert(op->method);
     if (op->method->destructor)
@@ -73,7 +70,7 @@ opcode_execute(const opcode_ty *op, struct opcode_context_ty *icp)
 {
     opcode_status_ty status;
 
-    trace(("opcode_execute(op = %08lX)\n{\n", (long)op));
+    trace(("opcode_execute(op = %p)\n{\n", op));
     assert(op);
     assert(op->method);
     assert(op->method->execute);
@@ -104,7 +101,7 @@ opcode_script(const opcode_ty *op, struct opcode_context_ty *icp)
 {
     opcode_status_ty status;
 
-    trace(("opcode_script(op = %08lX)\n{\n", (long)op));
+    trace(("opcode_script(op = %p)\n{\n", op));
     assert(op);
     assert(op->method);
     assert(op->method->script);
@@ -134,13 +131,13 @@ opcode_script(const opcode_ty *op, struct opcode_context_ty *icp)
 void
 opcode_disassemble(const opcode_ty *op)
 {
-    trace(("opcode_disassemble(op = %08lX)\n{\n", (long)op));
+    trace(("opcode_disassemble(op = %p)\n{\n", op));
     assert(op);
     assert(op->method);
     printf("%s", op->method->name);
     if (op->method->disassemble)
     {
-        printf("\t");
+        printf(" ");
         op->method->disassemble(op);
     }
     trace(("}\n"));
