@@ -1,11 +1,10 @@
 /*
  *      cook - file construction tool
- *      Copyright (C) 1997, 1998, 2001, 2006, 2007 Peter Miller;
- *      All rights reserved.
+ *      Copyright (C) 1997, 1998, 2001, 2006-2009 Peter Miller
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
- *      the Free Software Foundation; either version 2 of the License, or
+ *      the Free Software Foundation; either version 3 of the License, or
  *      (at your option) any later version.
  *
  *      This program is distributed in the hope that it will be useful,
@@ -14,10 +13,8 @@
  *      GNU General Public License for more details.
  *
  *      You should have received a copy of the GNU General Public License
- *      along with this program; if not, write to the Free Software
- *      Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
- *
- * MANIFEST: functions to manipulate assignment opcodes
+ *      along with this program. If not, see
+ *      <http://www.gnu.org/licenses/>.
  */
 
 #include <common/ac/stdio.h>
@@ -159,7 +156,7 @@ disassemble(const opcode_ty *op)
     this = (const opcode_assign_ty *)op;
     if (this->pos.pos_name && this->pos.pos_name->str_length)
     {
-        printf("\t# %s:%d", this->pos.pos_name->str_text, this->pos.pos_line);
+        printf(" # %s:%d", this->pos.pos_name->str_text, this->pos.pos_line);
     }
     trace(("}\n"));
 }
@@ -212,7 +209,7 @@ opcode_assign_new(expr_position_ty *pp)
     op = opcode_new(&method);
     this = (opcode_assign_ty *)op;
     expr_position_copy_constructor(&this->pos, pp);
-    trace(("return %08lX;\n", (long)op));
+    trace(("return %p;\n", op));
     trace(("}\n"));
     return op;
 }
