@@ -1,11 +1,10 @@
 /*
  *      cook - file construction tool
- *      Copyright (C) 1997-1999, 2001, 2003, 2004, 2006, 2007 Peter Miller;
- *      All rights reserved.
+ *      Copyright (C) 1997-1999, 2001, 2003, 2004, 2006-2009 Peter Miller
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
- *      the Free Software Foundation; either version 2 of the License, or
+ *      the Free Software Foundation; either version 3 of the License, or
  *      (at your option) any later version.
  *
  *      This program is distributed in the hope that it will be useful,
@@ -14,10 +13,8 @@
  *      GNU General Public License for more details.
  *
  *      You should have received a copy of the GNU General Public License
- *      along with this program; if not, write to the Free Software
- *      Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
- *
- * MANIFEST: functions to manipulate command opcodes
+ *      along with this program. If not, see
+ *      <http://www.gnu.org/licenses/>.
  *
  * See also: cook/os.c::execute()
  */
@@ -659,7 +656,7 @@ execute(const opcode_ty *op, opcode_context_ty *ocp)
          * prepare for metering
          */
 #ifdef HAVE_WAIT3
-        if (option_test(OPTION_METER))
+        if (option_test(OPTION_METER) && !option_test(OPTION_SILENT))
         {
             if (!ocp->meter_p)
                 ocp->meter_p = meter_alloc();
@@ -685,7 +682,7 @@ resume:
          * Finish metering.
          */
 #ifdef HAVE_WAIT3
-        if (option_test(OPTION_METER))
+        if (option_test(OPTION_METER) && !option_test(OPTION_SILENT))
         {
             assert(ocp->meter_p);
             meter_print(ocp->meter_p);
@@ -922,7 +919,7 @@ disassemble(const opcode_ty *op)
     this = (const opcode_command_ty *)op;
     printf
     (
-        "%d\t# %s:%d",
+        "%d # %s:%d",
         this->input,
         this->pos.pos_name->str_text,
         this->pos.pos_line
@@ -979,7 +976,7 @@ opcode_command_new(int input, const expr_position_ty *pp)
     this = (opcode_command_ty *)op;
     this->input = input;
     expr_position_copy_constructor(&this->pos, pp);
-    trace(("return %08lX;\n", (long)op));
+    trace(("return %p;\n", op));
     trace(("}\n"));
     return op;
 }
