@@ -1,11 +1,10 @@
 /*
  *      cook - file construction tool
- *      Copyright (C) 1997, 2006, 2007 Peter Miller;
- *      All rights reserved.
+ *      Copyright (C) 1997, 2006-2009 Peter Miller
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
- *      the Free Software Foundation; either version 2 of the License, or
+ *      the Free Software Foundation; either version 3 of the License, or
  *      (at your option) any later version.
  *
  *      This program is distributed in the hope that it will be useful,
@@ -14,10 +13,8 @@
  *      GNU General Public License for more details.
  *
  *      You should have received a copy of the GNU General Public License
- *      along with this program; if not, write to the Free Software
- *      Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
- *
- * MANIFEST: functions to manipulate labels
+ *      along with this program. If not, see
+ *      <http://www.gnu.org/licenses/>.
  */
 
 #include <common/mem.h>
@@ -52,7 +49,7 @@ opcode_label_new(void)
     lp->npending = 0;
     lp->npending_max = 0;
     lp->pending = 0;
-    trace(("return %08lX;\n", (long)lp));
+    trace(("return %p;\n", lp));
     trace(("}\n"));
     return lp;
 }
@@ -73,7 +70,7 @@ opcode_label_new(void)
 void
 opcode_label_delete(opcode_label_ty *lp)
 {
-    trace(("opcode_label_delete(lp = %08lX)\n{\n", (long)lp));
+    trace(("opcode_label_delete(lp = %p)\n{\n", lp));
     if (lp->pending)
         mem_free(lp->pending);
     lp->pc = (size_t) (-1);
@@ -106,7 +103,7 @@ opcode_label_define(opcode_label_ty *lp, size_t where)
 {
     size_t          j;
 
-    trace(("opcode_label_define(lp = %08lX)\n{\n", (long)lp));
+    trace(("opcode_label_define(lp = %p)\n{\n", lp));
     assert(lp->pc == (size_t)(-1));
     lp->pc = where;
     trace(("pc = %ld\n", (long)lp->pc));
@@ -141,7 +138,7 @@ opcode_label_define(opcode_label_ty *lp, size_t where)
 void
 opcode_label_refer(opcode_label_ty *lp, size_t *where)
 {
-    trace(("opcode_label_refer(lp = %08lX)\n{\n", (long)lp));
+    trace(("opcode_label_refer(lp = %p)\n{\n", lp));
     *where = (size_t) (-1);
     if (lp->pc == (size_t) (-1))
     {
