@@ -1,11 +1,10 @@
 /*
  *      cook - file construction tool
- *      Copyright (C) 1993-2007 Peter Miller;
- *      All rights reserved.
+ *      Copyright (C) 1993-2009 Peter Miller
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
- *      the Free Software Foundation; either version 2 of the License, or
+ *      the Free Software Foundation; either version 3 of the License, or
  *      (at your option) any later version.
  *
  *      This program is distributed in the hope that it will be useful,
@@ -14,10 +13,8 @@
  *      GNU General Public License for more details.
  *
  *      You should have received a copy of the GNU General Public License
- *      along with this program; if not, write to the Free Software
- *      Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
- *
- * MANIFEST: functions to manage command line options
+ *      along with this program. If not, see
+ *      <http://www.gnu.org/licenses/>.
  *
  * The options may be set at various levels.  The level with the highest
  * precedence which has actually been set is used to determine the option
@@ -44,7 +41,7 @@
  * cook/option.h
  *     to define the OPTION_ value
  * cook/option.c
- *     option_tidyup()
+ *     option_tidy_up()
  *         if the option defaults to true
  *     option_set_errors()
  *         if the option should be turned off once cookbook errors
@@ -55,7 +52,7 @@
  *     to define the RF_ values (RF stands for Recipe Flag)
  * cook/flag.c
  *     to define the RF_ names
- * langu.flags.so
+ * lib/en/user-guide/langu.flags.so
  *     to document the recipe flag
  *
  * If you choose to make it a command line option,
@@ -290,6 +287,7 @@ option_tidy_up(void)
     trace(("option_tidy_up()\n{\n"));
     option_set(OPTION_ACTION, OPTION_LEVEL_DEFAULT, 1);
     option_set(OPTION_CASCADE, OPTION_LEVEL_DEFAULT, 1);
+    option_set(OPTION_CTIME, OPTION_LEVEL_DEFAULT, 1);
     option_set(OPTION_FINGERPRINT_WRITE, OPTION_LEVEL_DEFAULT, 1);
     option_set(OPTION_INCLUDE_COOKED, OPTION_LEVEL_DEFAULT, 1);
     option_set(OPTION_INCLUDE_COOKED_WARNING, OPTION_LEVEL_DEFAULT, 1);
@@ -494,12 +492,18 @@ option_number_name(option_number_ty o)
     case OPTION_CMDFILE:
         return "OPTION_CMDFILE";
 
+    case OPTION_CTIME:
+        return "OPTION_CTIME";
+
     case OPTION_DISASSEMBLE:
         return "OPTION_DISASSEMBLE";
 
     case OPTION_ERROK:
         return "OPTION_ERROK";
 
+    case OPTION_FILE_SIZE_STATISTICS:
+        return "OPTION_FILE_SIZE_STATISTICS";
+
     case OPTION_FINGERPRINT:
         return "OPTION_FINGERPRINT";
 
