@@ -1,11 +1,10 @@
 /*
  *      cook - file construction tool
- *      Copyright (C) 1993-1997, 1999, 2001, 2003, 2006, 2007 Peter Miller;
- *      All rights reserved.
+ *      Copyright (C) 1993-1997, 1999, 2001, 2003, 2006-2009 Peter Miller
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
- *      the Free Software Foundation; either version 2 of the License, or
+ *      the Free Software Foundation; either version 3 of the License, or
  *      (at your option) any later version.
  *
  *      This program is distributed in the hope that it will be useful,
@@ -14,10 +13,8 @@
  *      GNU General Public License for more details.
  *
  *      You should have received a copy of the GNU General Public License
- *      along with this program; if not, write to the Free Software
- *      Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
- *
- * MANIFEST: interface definition for cook/option.c
+ *      along with this program. If not, see
+ *      <http://www.gnu.org/licenses/>.
  *
  *
  * If you are going to add a new recipe flag (set by the "set" statement,
@@ -38,7 +35,7 @@
  *     to define the RF_ values (RF stands for Recipe Flag)
  * cook/flag.c
  *     to define the RF_ names
- * langu.flags.so
+ * lib/en/user-guide/langu.flags.so
  *     to document the recipe flag
  *
  * If you choose to make it a command line option,
@@ -85,9 +82,11 @@ enum option_number_ty
         OPTION_BOOK,
         OPTION_CASCADE,         /* do (not) cascade ingredients */
         OPTION_CMDFILE,         /* generate a command file */
+        OPTION_CTIME,           /* use both st_ctime and st_mtime */
         OPTION_DISASSEMBLE,     /* undocumented: disassemble opcode lists after
                                    compilation */
         OPTION_ERROK,           /* ignore error returns from commands */
+        OPTION_FILE_SIZE_STATISTICS, /* print file size statistics after run */
         OPTION_FINGERPRINT,     /* remember file fingerprints */
         OPTION_FINGERPRINT_WRITE, /* preserve fingerprints if taken */
         OPTION_FORCE,           /* always execute the commands */
