@@ -1,11 +1,10 @@
 /*
  *      cook - file construction tool
- *      Copyright (C) 1995-2001, 2004, 2006, 2007 Peter Miller;
- *      All rights reserved.
+ *      Copyright (C) 1995-2001, 2004, 2006-2009 Peter Miller
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
- *      the Free Software Foundation; either version 2 of the License, or
+ *      the Free Software Foundation; either version 3 of the License, or
  *      (at your option) any later version.
  *
  *      This program is distributed in the hope that it will be useful,
@@ -14,10 +13,8 @@
  *      GNU General Public License for more details.
  *
  *      You should have received a copy of the GNU General Public License
- *      along with this program; if not, write to the Free Software
- *      Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
- *
- * MANIFEST: functions to isolate operating system interface
+ *      along with this program. If not, see
+ *      <http://www.gnu.org/licenses/>.
  */
 
 #include <common/ac/errno.h>
@@ -562,11 +559,17 @@ exit_status(char *cmd, int status, int errok)
             sub_var_set_long(scp, "Number", a);
             if (errok)
             {
-                error_intl
-                (
-                    scp,
-                    i18n("command $filename: exit status $number (ignored)")
-                );
+                int             silent;
+
+                silent = option_test(OPTION_SILENT);
+                if (!silent)
+                {
+                    error_intl
+                    (
+                        scp,
+                        i18n("command $filename: exit status $number (ignored)")
+                    );
+                }
             }
             else
             {
@@ -585,7 +588,7 @@ exit_status(char *cmd, int status, int errok)
          */
         scp = sub_context_new();
         sub_var_set_charstar(scp, "File_Name", cmd);
-        sub_var_set_charstar(scp, "Name", strsignal(c));
+        sub_var_set_charstar(scp, "Name", safe_strsignal(c));
         if (b)
         {
             error_intl
@@ -973,7 +976,7 @@ os_entryname(string_ty *path)
 {
     char            *cp;
 
-    trace(("os_entryname(path = %08lX)\n{\n", path));
+    trace(("os_entryname(path = %p)\n{\n", path));
     trace_string(path->str_text);
     cp = strrchr(path->str_text, '/');
     if (cp)
@@ -981,7 +984,7 @@ os_entryname(string_ty *path)
     else
         path = str_copy(path);
     trace_string(path->str_text);
-    trace(("return %08lX;\n", path));
+    trace(("return %p;\n", path));
     trace(("}\n"));
     return path;
 }
@@ -1011,7 +1014,7 @@ os_dirname(string_ty *path)
 {
     char            *cp;
 
-    trace(("os_dirname(path = %08lX)\n{\n", path));
+    trace(("os_dirname(path = %p)\n{\n", path));
     trace_string(path->str_text);
     cp = strrchr(path->str_text, '/');
     if (cp)
@@ -1026,7 +1029,7 @@ os_dirname(string_ty *path)
     else
         path = os_curdir();
     trace_string(path->str_text);
-    trace(("return %08lX;\n", path));
+    trace(("return %p;\n", path));
     trace(("}\n"));
     return path;
 }
