@@ -1,11 +1,10 @@
 /*
  *      cook - file construction tool
- *      Copyright (C) 1999, 2001, 2006, 2007 Peter Miller;
- *      All rights reserved.
+ *      Copyright (C) 1999, 2001, 2006-2009 Peter Miller
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
- *      the Free Software Foundation; either version 2 of the License, or
+ *      the Free Software Foundation; either version 3 of the License, or
  *      (at your option) any later version.
  *
  *      This program is distributed in the hope that it will be useful,
@@ -14,10 +13,8 @@
  *      GNU General Public License for more details.
  *
  *      You should have received a copy of the GNU General Public License
- *      along with this program; if not, write to the Free Software
- *      Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
- *
- * MANIFEST: functions to manipulate dirnam_relats
+ *      along with this program. If not, see
+ *      <http://www.gnu.org/licenses/>.
  */
 
 #include <common/ac/string.h>
@@ -50,7 +47,7 @@ os_dirname_relative(string_ty *path)
 {
     char            *cp;
 
-    trace(("os_dirname_relative(path = %08lX)\n{\n", path));
+    trace(("os_dirname_relative(path = %p)\n{\n", path));
     trace_string(path->str_text);
     cp = strrchr(path->str_text, '/');
     if (cp)
@@ -65,7 +62,7 @@ os_dirname_relative(string_ty *path)
     else
         path = str_from_c(".");
     trace_string(path->str_text);
-    trace(("return %08lX;\n", path));
+    trace(("return %p;\n", path));
     trace(("}\n"));
     return path;
 }
