@@ -1,11 +1,10 @@
 /*
  *      cook - file construction tool
- *      Copyright (C) 1992-1994, 1997-1999, 2001, 2002, 2006, 2007 Peter Miller;
- *      All rights reserved.
+ *      Copyright (C) 1992-1994, 1997-1999, 2001, 2002, 2006-2009 Peter Miller
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
- *      the Free Software Foundation; either version 2 of the License, or
+ *      the Free Software Foundation; either version 3 of the License, or
  *      (at your option) any later version.
  *
  *      This program is distributed in the hope that it will be useful,
@@ -14,10 +13,8 @@
  *      GNU General Public License for more details.
  *
  *      You should have received a copy of the GNU General Public License
- *      along with this program; if not, write to the Free Software
- *      Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
- *
- * MANIFEST: functions to manipulate the stat cache
+ *      along with this program. If not, see
+ *      <http://www.gnu.org/licenses/>.
  */
 
 #include <common/ac/string.h>
@@ -25,15 +22,16 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 
-#include <cook/archive.h>
 #include <common/error_intl.h>
-#include <cook/fingerprint.h>
-#include <cook/fingerprint/value.h>
 #include <common/mem.h>
-#include <cook/option.h>
-#include <cook/stat.cache.h>
 #include <common/symtab.h>
 #include <common/trace.h>
+#include <cook/archive.h>
+#include <cook/fingerprint.h>
+#include <cook/fingerprint/value.h>
+#include <cook/option.h>
+#include <cook/option.h>
+#include <cook/stat.cache.h>
 
 
 typedef struct cache_ty cache_ty;
@@ -401,7 +399,14 @@ stat_cache(string_ty *path, cache_ty *cp, int follow_links)
          * mod time.  The st_ctime field records when the inode's
          * meta-data (e.g. the st_mtime member) was last changed.
          */
-        if (option_test(OPTION_FINGERPRINT) && st.st_mtime < st.st_ctime)
+        if
+        (
+            option_test(OPTION_FINGERPRINT)
+        &&
+            option_test(OPTION_CTIME)
+        &&
+            st.st_mtime < st.st_ctime
+        )
             st.st_mtime = st.st_ctime;
 
         cp->oldest = st.st_mtime;
@@ -450,8 +455,8 @@ stat_cache_newest(string_ty *path, int follow_links)
     cache_ty        cache;
     sub_context_ty  *scp;
 
-    trace(("stat_cache_newest(path = \"%s\", lnk = %d)\n{\n",
-        (long)path->str_text, follow_links));
+    trace(("stat_cache_newest(path = \"%s\", lnk = %d)\n{\n", path->str_text,
+        follow_links));
     if (stat_cache(path, &cache, !!follow_links))
     {
         trace(("Bzzt!\n"));
@@ -544,8 +549,8 @@ stat_cache_oldest(string_ty *path, int follow_links)
     cache_ty        cache;
     sub_context_ty  *scp;
 
-    trace(("stat_cache_oldest(path = \"%s\", lnk = %d)\n{\n",
-        (long)path->str_text, follow_links));
+    trace(("stat_cache_oldest(path = \"%s\", lnk = %d)\n{\n", path->str_text,
+        follow_links));
     if (stat_cache(path, &cache, !!follow_links))
     {
         trace(("Bzzt!\n"));
@@ -729,3 +734,35 @@ stat_cache_clear(string_ty *path)
         symtab_delete(symtab[1], path);
     trace(("}\n"));
 }
+
+
+static void
+dumper(symtab_ty *stp, string_ty *key, void *data, void *arg)
+{
+    struct stat     st;
+
+    (void)stp;
+    (void)data;
+    if (stat(key->str_text, &st) >= 0 && S_ISREG(st.st_mode))
+    {
+        FILE            *fp;
+
+        fp = arg;
+        fprintf(fp, "%lld %s\n", (long long)st.st_size, key->str_text);
+    }
+}
+
+
+void
+stat_cache_dump(void)
+{
+    if (!option_test(OPTION_FILE_SIZE_STATISTICS))
+        return;
+    if (!symtab[1])
+        return;
+    FILE *fp = fopen("file-size-statistics.txt", "w");
+    if (!fp)
+        return;
+    symtab_walk(symtab[1], dumper, fp);
+    fclose(fp);
+}
