@@ -1,11 +1,10 @@
 /*
  *      cook - file construction tool
- *      Copyright (C) 1994, 1997, 1998, 2006, 2007 Peter Miller;
- *      All rights reserved.
+ *      Copyright (C) 1994, 1997, 1998, 2006-2009 Peter Miller
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
- *      the Free Software Foundation; either version 2 of the License, or
+ *      the Free Software Foundation; either version 3 of the License, or
  *      (at your option) any later version.
  *
  *      This program is distributed in the hope that it will be useful,
@@ -14,10 +13,8 @@
  *      GNU General Public License for more details.
  *
  *      You should have received a copy of the GNU General Public License
- *      along with this program; if not, write to the Free Software
- *      Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
- *
- * MANIFEST: interface definition for cook/stat.cache.c
+ *      along with this program. If not, see
+ *      <http://www.gnu.org/licenses/>.
  */
 
 #ifndef COOK_STAT_CACHE_H
@@ -31,4 +28,11 @@ time_t stat_cache_newest(string_ty *, int);
 void stat_cache_set(string_ty *, time_t, int);
 void stat_cache_clear(string_ty *);
 
+/**
+  * The stat_cache_dump function is used to dump the contents of the
+  * stat cache to a file.  Well, actually, just the file sizes, because
+  * all the other stuff is already in the .cook.fp file(s).
+  */
+void stat_cache_dump(void);
+
 #endif /* COOK_STAT_CACHE_H */
