@@ -1,11 +1,10 @@
 /*
  *      cook - file construction tool
- *      Copyright (C) 1998, 2006, 2007 Peter Miller;
- *      All rights reserved.
+ *      Copyright (C) 1998, 2006-2009 Peter Miller
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
- *      the Free Software Foundation; either version 2 of the License, or
+ *      the Free Software Foundation; either version 3 of the License, or
  *      (at your option) any later version.
  *
  *      This program is distributed in the hope that it will be useful,
@@ -14,10 +13,8 @@
  *      GNU General Public License for more details.
  *
  *      You should have received a copy of the GNU General Public License
- *      along with this program; if not, write to the Free Software
- *      Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
- *
- * MANIFEST: functions to manipulate assign-append statement nodes
+ *      along with this program. If not, see
+ *      <http://www.gnu.org/licenses/>.
  */
 
 #include <cook/expr.h>
@@ -64,7 +61,7 @@ destructor(stmt_ty *sp)
 {
     stmt_append_ty  *this;
 
-    trace(("destructor(sp = %08X)\n{\n", sp));
+    trace(("destructor(sp = %p)\n{\n", sp));
     assert(sp);
     /* assert(sp->method == &method); */
     this = (stmt_append_ty *)sp;
@@ -98,7 +95,7 @@ code_generate(stmt_ty *sp, opcode_list_ty *olp)
     static expr_ty  *cascade_for_expr;
     expr_position_ty *pp;
 
-    trace(("code_generate(sp = %08X)\n{\n", sp));
+    trace(("code_generate(sp = %p)\n{\n", sp));
     assert(sp);
     this = (stmt_append_ty *)sp;
 
@@ -233,7 +230,7 @@ stmt_append_new(expr_list_ty *name, expr_list_ty *value)
     this = (stmt_append_ty *)sp;
     expr_list_copy_constructor(&this->name, name);
     expr_list_copy_constructor(&this->value, value);
-    trace(("return %8.8lX;\n", (long)sp));
+    trace(("return %p;\n", sp));
     trace(("}\n"));
     return sp;
 }
