@@ -1,11 +1,10 @@
 /*
  *      cook - file construction tool
- *      Copyright (C) 1997, 1998, 2006, 2007 Peter Miller;
- *      All rights reserved.
+ *      Copyright (C) 1997, 1998, 2006-2009 Peter Miller
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
- *      the Free Software Foundation; either version 2 of the License, or
+ *      the Free Software Foundation; either version 3 of the License, or
  *      (at your option) any later version.
  *
  *      This program is distributed in the hope that it will be useful,
@@ -14,10 +13,8 @@
  *      GNU General Public License for more details.
  *
  *      You should have received a copy of the GNU General Public License
- *      along with this program; if not, write to the Free Software
- *      Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
- *
- * MANIFEST: functions to manipulate loop statement nodes
+ *      along with this program. If not, see
+ *      <http://www.gnu.org/licenses/>.
  */
 
 #include <common/error_intl.h>
@@ -59,7 +56,7 @@ destructor(stmt_ty *sp)
 {
     stmt_loop_ty    *this;
 
-    trace(("stmt_loop::destructor(sp = %08X)\n{\n", sp));
+    trace(("stmt_loop::destructor(sp = %p)\n{\n", sp));
     assert(sp);
     /* assert(sp->method == &method); */
     this = (stmt_loop_ty *) sp;
@@ -92,7 +89,7 @@ code_generate(stmt_ty *sp, opcode_list_ty *olp)
     opcode_label_ty *continue_hold;
     opcode_label_ty *break_hold;
 
-    trace(("stmt_loop::code_generate(sp = %08X)\n{\n", sp));
+    trace(("stmt_loop::code_generate(sp = %p)\n{\n", sp));
     assert(sp);
     this = (stmt_loop_ty *)sp;
     assert(this->body);
@@ -165,12 +162,12 @@ stmt_loop_new(stmt_ty *body)
     stmt_ty         *sp;
     stmt_loop_ty    *this;
 
-    trace(("stmt_loop_new(body = %08lX)\n{\n", (long)body));
+    trace(("stmt_loop_new(body = %p)\n{\n", body));
     sp = stmt_private_new(&method);
     this = (stmt_loop_ty *)sp;
     this->body = stmt_copy(body);
     assert(this->body);
-    trace(("return %8.8lX;\n", (long)sp));
+    trace(("return %p;\n", sp));
     trace(("}\n"));
     return sp;
 }
@@ -205,7 +202,7 @@ loopstop_destructor(stmt_ty *sp)
 {
     stmt_loopstop_ty *this;
 
-    trace(("stmt_loopstop::destructor(sp = %08X)\n{\n", sp));
+    trace(("stmt_loopstop::destructor(sp = %p)\n{\n", sp));
     assert(sp);
     /* assert(sp->method == &loopstop_method); */
     this = (stmt_loopstop_ty *)sp;
@@ -235,7 +232,7 @@ loopstop_code_generate(stmt_ty *sp, opcode_list_ty *olp)
     stmt_loopstop_ty *this;
     stmt_result_ty  status;
 
-    trace(("stmt_loopstop::code_generate(sp = %08X)\n{\n", sp));
+    trace(("stmt_loopstop::code_generate(sp = %p)\n{\n", sp));
     assert(sp);
     this = (stmt_loopstop_ty *)sp;
     status = STMT_OK;
@@ -308,7 +305,7 @@ stmt_loopstop_new(expr_position_ty *pp)
     sp = stmt_private_new(&loopstop_method);
     this = (stmt_loopstop_ty *)sp;
     expr_position_copy_constructor(&this->pos, pp);
-    trace(("return %8.8lX;\n", (long)sp));
+    trace(("return %p;\n", sp));
     trace(("}\n"));
     return sp;
 }
