@@ -1,11 +1,10 @@
 /*
  *      cook - file construction tool
- *      Copyright (C) 1997, 2006, 2007 Peter Miller;
- *      All rights reserved.
+ *      Copyright (C) 1997, 2006-2009 Peter Miller
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
- *      the Free Software Foundation; either version 2 of the License, or
+ *      the Free Software Foundation; either version 3 of the License, or
  *      (at your option) any later version.
  *
  *      This program is distributed in the hope that it will be useful,
@@ -14,10 +13,8 @@
  *      GNU General Public License for more details.
  *
  *      You should have received a copy of the GNU General Public License
- *      along with this program; if not, write to the Free Software
- *      Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
- *
- * MANIFEST: functions to manipulate nop statement nodes
+ *      along with this program. If not, see
+ *      <http://www.gnu.org/licenses/>.
  */
 
 #include <cook/stmt.h>
@@ -43,7 +40,7 @@
 static stmt_result_ty
 code_generate(stmt_ty *sp, struct opcode_list_ty *olp)
 {
-    trace(("code_generate(sp = %08X)\n{\n", sp));
+    trace(("code_generate(sp = %p)\n{\n", sp));
     (void)sp;
     (void)olp;
     assert(sp);
@@ -100,7 +97,7 @@ stmt_nop_new(void)
 
     trace(("stmt_nop_new()\n{\n"));
     sp = stmt_private_new(&method);
-    trace(("return %8.8lX;\n", (long)sp));
+    trace(("return %p;\n", sp));
     trace(("}\n"));
     return sp;
 }
