@@ -1,11 +1,10 @@
 /*
  *      cook - file construction tool
- *      Copyright (C) 1998, 1999, 2001, 2006, 2007 Peter Miller;
- *      All rights reserved.
+ *      Copyright (C) 1998, 1999, 2001, 2006-2008 Peter Miller
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
- *      the Free Software Foundation; either version 2 of the License, or
+ *      the Free Software Foundation; either version 3 of the License, or
  *      (at your option) any later version.
  *
  *      This program is distributed in the hope that it will be useful,
@@ -14,10 +13,8 @@
  *      GNU General Public License for more details.
  *
  *      You should have received a copy of the GNU General Public License
- *      along with this program; if not, write to the Free Software
- *      Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
- *
- * MANIFEST: functions to manipulate sniffs
+ *      along with this program. If not, see
+ *      <http://www.gnu.org/licenses/>.
  */
 
 #include <common/ac/ctype.h>
@@ -379,9 +376,9 @@ sniff(char *ifn, char *ofn)
 
     fprintf(ofp, ".cook.bom.dir = [relative_dirname [__FILE__]];\n");
     fprintf(ofp, "if [in [.cook.bom.dir] \".\"] then\n");
-    fprintf(ofp, "\t.cook.bom/dir = '';\n");
+    fprintf(ofp, "    .cook.bom/dir = '';\n");
     fprintf(ofp, "else\n");
-    fprintf(ofp, "\t.cook.bom/dir = [.cook.bom.dir]/;\n");
+    fprintf(ofp, "    .cook.bom/dir = [.cook.bom.dir]/;\n");
 
     /*
      * Output the normal files.
@@ -391,9 +388,9 @@ sniff(char *ifn, char *ofn)
     for (j = 0; j < files.nstrings; ++j)
     {
         filename = files.string[j];
-        fprintf(ofp, "\t%s\n", filename->str_text);
+        fprintf(ofp, "    %s\n", filename->str_text);
     }
-    fprintf(ofp, "\t;\n");
+    fprintf(ofp, "    ;\n");
     fprintf
     (
         ofp,
@@ -409,9 +406,9 @@ sniff(char *ifn, char *ofn)
     for (j = 0; j < specials.nstrings; ++j)
     {
         filename = specials.string[j];
-        fprintf(ofp, "\t%s\n", filename->str_text);
+        fprintf(ofp, "    %s\n", filename->str_text);
     }
-    fprintf(ofp, "\t;\n");
+    fprintf(ofp, "    ;\n");
     fprintf
     (
         ofp,
@@ -427,9 +424,9 @@ sniff(char *ifn, char *ofn)
     for (j = 0; j < directories.nstrings; ++j)
     {
         filename = directories.string[j];
-        fprintf(ofp, "\t%s\n", filename->str_text);
+        fprintf(ofp, "    %s\n", filename->str_text);
     }
-    fprintf(ofp, "\t;\n");
+    fprintf(ofp, "    ;\n");
     fprintf
     (
         ofp,
@@ -452,7 +449,7 @@ sniff(char *ifn, char *ofn)
         (
             ofp,
             "#include-cooked-nowarn [prepost %s[.cook.bom/dir] %s \\\n"
-                "\t[directories_in_[.cook.bom.dir]]]\n",
+                "    [directories_in_[.cook.bom.dir]]]\n",
             prefix->str_text,
             suffix->str_text
         );
@@ -469,9 +466,9 @@ sniff(char *ifn, char *ofn)
         );
         fprintf(ofp, ".cook.bom.dir = [relative_dirname [__FILE__]];\n");
         fprintf(ofp, "if [in [.cook.bom.dir] \".\"] then\n");
-        fprintf(ofp, "\t.cook.bom/dir = '';\n");
+        fprintf(ofp, "    .cook.bom/dir = '';\n");
         fprintf(ofp, "else\n");
-        fprintf(ofp, "\t.cook.bom/dir = [.cook.bom.dir]/;\n");
+        fprintf(ofp, "    .cook.bom/dir = [.cook.bom.dir]/;\n");
     }
 
     /*
@@ -486,8 +483,8 @@ sniff(char *ifn, char *ofn)
         (
             ofp,
             "if [defined all_files_in_[.cook.bom/dir]%s] then\n"
-                "\tall_files_in_[.cook.bom.dir] +=\n"
-                "\t\t[addprefix %s/ [all_files_in_[.cook.bom/dir]%s]];\n",
+                "    all_files_in_[.cook.bom.dir] +=\n"
+                "        [addprefix %s/ [all_files_in_[.cook.bom/dir]%s]];\n",
             filename->str_text,
             filename->str_text,
             filename->str_text
@@ -497,8 +494,8 @@ sniff(char *ifn, char *ofn)
         (
             ofp,
             "if [defined all_specials_in_[.cook.bom/dir]%s] then\n"
-                "\tall_specials_in_[.cook.bom.dir] +=\n"
-                "\t\t[addprefix %s/ [all_specials_in_[.cook.bom/dir]%s]];\n",
+            "    all_specials_in_[.cook.bom.dir] +=\n"
+            "        [addprefix %s/ [all_specials_in_[.cook.bom/dir]%s]];\n",
             filename->str_text,
             filename->str_text,
             filename->str_text
@@ -508,8 +505,8 @@ sniff(char *ifn, char *ofn)
         (
             ofp,
             "if [defined all_directories_in_[.cook.bom/dir]%s] then\n"
-                "\tall_directories_in_[.cook.bom.dir] +=\n"
-                "\t\t[addprefix %s/ [all_directories_in_[.cook.bom/dir]%s]];\n",
+            "    all_directories_in_[.cook.bom.dir] +=\n"
+            "        [addprefix %s/ [all_directories_in_[.cook.bom/dir]%s]];\n",
             filename->str_text,
             filename->str_text,
             filename->str_text
