@@ -1,12 +1,11 @@
 #!/bin/sh
 #
 #       cook - file construction tool
-#       Copyright (C) 1993-1997, 1999, 2001, 2003, 2004, 2007 Peter Miller;
-#       All rights reserved.
+#       Copyright (C) 1993-1997, 1999, 2001, 2003, 2004, 2007-2009 Peter Miller
 #
 #       This program is free software; you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
-#       the Free Software Foundation; either version 2 of the License, or
+#       the Free Software Foundation; either version 3 of the License, or
 #       (at your option) any later version.
 #
 #       This program is distributed in the hope that it will be useful,
@@ -15,10 +14,8 @@
 #       GNU General Public License for more details.
 #
 #       You should have received a copy of the GNU General Public License
-#       along with this program; if not, write to the Free Software
-#       Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
-#
-# MANIFEST: shell script to generate RedHat spec file
+#       along with this program. If not, see
+#       <http://www.gnu.org/licenses/>.
 #
 version=${version-0.0.0}
 echo 'Summary: a file construction tool'
@@ -27,8 +24,8 @@ echo "Version: ${version}"
 echo 'Release: 1'
 echo 'Copyright: GPL'
 echo 'Group: Development/Building'
-echo "Source: http://www.canb.auug.org.au/~millerp/cook/cook-${version}.tar.gz"
-echo 'URL: http://www.canb.auug.org.au/~millerp/cook/'
+echo "Source: http://miller.emu.id.au/pmiller/cook/cook-${version}.tar.gz"
+echo 'URL: http://miller.emu.id.au/pmiller/cook/'
 echo 'BuildRoot: /tmp/cook-build-root'
 echo 'Icon: cook-${version}/cook.png'
 echo 'Provides: perl(host_lists.pl)'
