@@ -2,11 +2,11 @@
 .\"     cook - file construction tool
 .\"     Copyright (C) 2002 Aryeh M. Friedman
 .\"     Groff formatting general editorial work
-.\"     Copyright (C) 2002, 2003, 2007 Peter Miller
+.\"     Copyright (C) 2002, 2003, 2007, 2009 Peter Miller
 .\"
 .\"     This program is free software; you can redistribute it and/or modify
 .\"     it under the terms of the GNU General Public License as published by
-.\"     the Free Software Foundation; either version 2 of the License, or
+.\"     the Free Software Foundation; either version 3 of the License, or
 .\"     (at your option) any later version.
 .\"
 .\"     This program is distributed in the hope that it will be useful,
@@ -15,10 +15,8 @@
 .\"     GNU General Public License for more details.
 .\"
 .\"     You should have received a copy of the GNU General Public License
-.\"     along with this program; if not, write to the Free Software
-.\"     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
-.\"
-.\" MANIFEST: Tutorial
+.\"     along with this program. If not, see
+.\"     <http://www.gnu.org/licenses/>.
 .\"
 .if n .ftr CB B
 .if n .ftr CI I
@@ -103,7 +101,7 @@ Copyright \*(C) \*(Y) Peter Miller
 .sp
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2 of the License, or
+the Free Software Foundation; either version 3 of the License, or
 (at your option) any later version.
 .sp
 This program is distributed in the hope that it will be useful,
@@ -111,9 +109,8 @@ but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 .sp
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
+You should have received a copy of the GNU General Public License along
+with this program. If not, see <http://www.gnu.org/licenses/>.
 .\" ------------------------------------------------------------------------
 .PH "'Cook''Tutorial'"
 .bp 1
@@ -1079,17 +1076,7 @@ be integrated using shell scripts.
 If you find any bugs in this tutorial please send a bug report
 to Aryeh M. Friedman \f[CW]<aryeh@m-net.arbornet.org>\fP.
 .P
-The Cook web site is \f[CW]http:\%//www.canb.auug.org.au\%/~millerp\%/cook/\fP
+The Cook web site is \f[CW]http:\%//miller.emu.id.au\%/pmiller\%/cook/\fP
 .P
 If you want to contact Cook's author, send email to
-Peter Miller \f[CW]<millerp@canb.auug.org.au>\fP.
-.\" .H 1 "Notes"
-.\" In the project that forced me to switch to Cook from make
-.\" there are multiple libraries each with a "includes.h" file that recursively
-.\" includes all the "local" includes and any other library headers needed (i.e.
-.\" libutils.h for example).  When the library is built the include.h file
-.\" has to be "cooked" in that it has to be scanned for local #include's and
-.\" each mentioned include file needs to be "sucked" into the main include,
-.\" this is done by a program called pack_h that is unique to that particular
-.\" project.  For various reasons the dependency checking in this case has
-.\" to be done by a shell script vs. c_incl.
+Peter Miller \f[CW]<pmiller@opensource.org.au>\fP.
