@@ -1,11 +1,10 @@
 .\"
 .\"     cook - file construction tool
-.\"     Copyright (C) 1990-1994, 1997, 1998, 2007 Peter Miller;
-.\"     All rights reserved.
+.\"     Copyright (C) 1990-1994, 1997, 1998, 2007-2009 Peter Miller
 .\"
 .\"     This program is free software; you can redistribute it and/or modify
 .\"     it under the terms of the GNU General Public License as published by
-.\"     the Free Software Foundation; either version 2 of the License, or
+.\"     the Free Software Foundation; either version 3 of the License, or
 .\"     (at your option) any later version.
 .\"
 .\"     This program is distributed in the hope that it will be useful,
@@ -14,10 +13,8 @@
 .\"     GNU General Public License for more details.
 .\"
 .\"     You should have received a copy of the GNU General Public License
-.\"     along with this program; if not, write to the Free Software
-.\"     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
-.\"
-.\" MANIFEST: Reference Manual
+.\"     along with this program. If not, see
+.\"     <http://www.gnu.org/licenses/>.
 .\"
 .\" must be formatted using "groff -s -t -mm refman.t | lpr"
 .\"
@@ -85,7 +82,7 @@ User Guide
 Peter Miller
 .ft I
 .ce 1
-millerp@canb.auug.org.au
+pmiller@opensource.org.au
 .ft P
 .\" ---------------------------------------------------------------------------
 .bp
@@ -106,13 +103,12 @@ are
 .br
 Copyright \*(C)
 .nr d) \n(.d
-\*(Y) Peter Miller;
+\*(Y) Peter Miller
 .if '\n(d)'\n(.d' .br
-All rights reserved.
 .sp
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2 of the License, or
+the Free Software Foundation; either version 3 of the License, or
 (at your option) any later version.
 .sp
 This program is distributed in the hope that it will be useful,
@@ -120,9 +116,8 @@ but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 .sp
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
+You should have received a copy of the GNU General Public License along
+with this program. If not, see <http://www.gnu.org/licenses/>.
 .\" ---------------------------------------------------------------------------
 .PH "'Cook''User Guide'"
 .bp 1
