@@ -1,11 +1,10 @@
 /*
  *      cook - file construction tool
- *      Copyright (C) 1994, 1997, 2001, 2006, 2007 Peter Miller;
- *      All rights reserved.
+ *      Copyright (C) 1994, 1997, 2001, 2006-2009 Peter Miller
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
- *      the Free Software Foundation; either version 2 of the License, or
+ *      the Free Software Foundation; either version 3 of the License, or
  *      (at your option) any later version.
  *
  *      This program is distributed in the hope that it will be useful,
@@ -14,10 +13,8 @@
  *      GNU General Public License for more details.
  *
  *      You should have received a copy of the GNU General Public License
- *      along with this program; if not, write to the Free Software
- *      Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
- *
- * MANIFEST: functions to manipulate assign statements
+ *      along with this program. If not, see
+ *      <http://www.gnu.org/licenses/>.
  */
 
 #include <make2cook/emit.h>
@@ -401,7 +398,7 @@ default_setting(string_ty *name)
         string_list_destructor(&wl);
     }
     result = stmt_assign_alloc(0, lhs, stmt_assign_op_default, rhs);
-    trace(("return %8.8lX;\n", (long)result));
+    trace(("return %p;\n", result));
     trace(("}\n"));
     return result;
 }
@@ -427,7 +424,7 @@ stmt_assign_default(stmt_ty *sp)
             result = default_setting(name);
             assert(string_list_member(&result->cdef, name));
             assert(string_list_member(&result->mdef, name));
-            trace(("return %d;\n", result));
+            trace(("return %p;\n", result));
             trace(("}\n"));
             return result;
         }
@@ -445,7 +442,7 @@ stmt_assign_default(stmt_ty *sp)
             result = default_setting(name);
             assert(string_list_member(&result->cdef, name));
             assert(string_list_member(&result->mdef, name));
-            trace(("return %d;\n", result));
+            trace(("return %p;\n", result));
             trace(("}\n"));
             return result;
         }
