@@ -1,12 +1,11 @@
 #!/bin/sh
 #
 #       cook - file construction tool
-#       Copyright (C) 1990-1994, 1997, 1998, 2003, 2007 Peter Miller;
-#       All rights reserved.
+#       Copyright (C) 1990-1994, 1997, 1998, 2003, 2007, 2008 Peter Miller
 #
 #       This program is free software; you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
-#       the Free Software Foundation; either version 2 of the License, or
+#       the Free Software Foundation; either version 3 of the License, or
 #       (at your option) any later version.
 #
 #       This program is distributed in the hope that it will be useful,
@@ -15,10 +14,8 @@
 #       GNU General Public License for more details.
 #
 #       You should have received a copy of the GNU General Public License
-#       along with this program; if not, write to the Free Software
-#       Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
-#
-# MANIFEST: test the cooktime program
+#       along with this program. If not, see
+#       <http://www.gnu.org/licenses/>.
 #
 tmp=${COOK_TMP:-/tmp}/$$
 PAGER=cat
@@ -83,11 +80,8 @@ $bin/cooktime victim -a 8-jan-85 -r > /dev/null
 if test $? -ne 0 ; then fail; fi
 
 # Check the filesystem granularity. Check for round up when tsg == 2
-TAB=`awk 'BEGIN{printf("\11")}' /dev/null`
-test $? -eq 0 || fail
-
-sed "s|<TAB>|$TAB|g" > test.ok << 'fubar'
-<TAB>modify Fri, 16 Feb 1996 12:34:58 GMT
+cat > test.ok << 'fubar'
+    modify Fri, 16 Feb 1996 12:34:58 GMT
 fubar
 if test $? -ne 0 ; then fail; fi
 
