@@ -1,12 +1,11 @@
 #!/bin/sh
 #
 #       cook - file construction tool
-#       Copyright (C) 1994, 1997, 1998, 2001, 2002, 2007 Peter Miller;
-#       All rights reserved.
+#       Copyright (C) 1994, 1997, 1998, 2001, 2002, 2007, 2008 Peter Miller
 #
 #       This program is free software; you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
-#       the Free Software Foundation; either version 2 of the License, or
+#       the Free Software Foundation; either version 3 of the License, or
 #       (at your option) any later version.
 #
 #       This program is distributed in the hope that it will be useful,
@@ -15,10 +14,8 @@
 #       GNU General Public License for more details.
 #
 #       You should have received a copy of the GNU General Public License
-#       along with this program; if not, write to the Free Software
-#       Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
-#
-# MANIFEST: Test the cookfp repeat functionality
+#       along with this program. If not, see
+#       <http://www.gnu.org/licenses/>.
 #
 work=${COOK_TMP:-/tmp}/$$
 PAGER=cat
@@ -90,11 +87,11 @@ if test $? -ne 0 ; then fail; fi
 cat > test.ok.uue << 'fubar'
 begin 644 test.ok
 M2F]816AD9FQ'>%ID4S@Y=$1D-7IP1G@P2E)*>5@P:S8W14@P2F]D-V%E=#1H
-M26I"+FA':&]N,'9E3C!"6E)F:3`U.$A:43`V53!*1`ET97-T+FEN"DIO6$5H
+M26I"+FA':&]N,'9E3C!"6E)F:3`U.$A:43`V53!*1"!T97-T+FEN"DIO6$5H
 M9&9L1WA:9%,X.71$9#5Z<$9X,$I22GE8,&LV-T5(,$IO9#=A970T:$EJ0BYH
-M1VAO;C!V94XP0EI29FDP-3A(6E$P-E4P2D0)<W1D:6X*2F]816AD9FQ'>%ID
+M1VAO;C!V94XP0EI29FDP-3A(6E$P-E4P2D0@<W1D:6X*2F]816AD9FQ'>%ID
 M4S@Y=$1D-7IP1G@P2E)*>5@P:S8W14@P2F]D-V%E=#1H26I"+FA':&]N,'9E
-<3C!"6E)F:3`U.$A:43`V53!*1`ET97-T+FEN"@``
+<3C!"6E)F:3`U.$A:43`V53!*1"!T97-T+FEN"@``
 `
 end
 fubar
