@@ -5,7 +5,7 @@
 #
 #       This program is free software; you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
-#       the Free Software Foundation; either version 2 of the License, or
+#       the Free Software Foundation; either version 3 of the License, or
 #       (at your option) any later version.
 #
 #       This program is distributed in the hope that it will be useful,
@@ -14,10 +14,8 @@
 #       GNU General Public License for more details.
 #
 #       You should have received a copy of the GNU General Public License
-#       along with this program; if not, write to the Free Software
-#       Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
-#
-# MANIFEST: Test the make2cook functionality
+#       along with this program. If not, see
+#       <http://www.gnu.org/licenses/>.
 #
 work=${COOK_TMP:-/tmp}/$$
 PAGER=cat
@@ -59,59 +57,57 @@ COOK_MESSAGE_LIBRARY=$work/no-such-dir
 export COOK_MESSAGE_LIBRARY
 unset LANG
 
-TAB=`awk 'BEGIN{printf("\11")}' /dev/null`
+TAB=`awk 'BEGIN{printf("%c",9)}' /dev/null`
 test $? -eq 0 || fail
 
 #
 # test the make2cook functionality
 #
-sed "s|<TAB>|$TAB|g" > test.in << 'fubar'
+cat > test.in << 'fubar'
 .SUFFIXES:
 
 libs_for_gcc = -lgnu
 normal_libs =
 
 ifeq ($(CC),gcc)
-foo: $(objects)
-<TAB>$(CC) -o foo $(objects) $(libs_for_gcc)
+foo: $(objects);$(CC) -o foo $(objects) $(libs_for_gcc)
 else
-foo: $(objects)
-<TAB>$(CC) -o foo $(objects) $(normals_libs)
+foo: $(objects);$(CC) -o foo $(objects) $(normals_libs)
 endif
 fubar
 if test $? -ne 0 ; then fail; fi
 
-sed "s|<TAB>|$TAB|g" > test.ok << 'fubar'
+cat > test.ok << 'fubar'
 if [not [defined normals_libs]] then
-<TAB>normals_libs = [getenv normals_libs];
+        normals_libs = [getenv normals_libs];
 if [not [defined objects]] then
-<TAB>objects = [getenv objects];
+        objects = [getenv objects];
 if [not [defined CC]] then
 {
-<TAB>CC = [getenv CC];
-<TAB>if [not [CC]] then
-<TAB><TAB>CC = cc;
+        CC = [getenv CC];
+        if [not [CC]] then
+                CC = cc;
 }
 
 if [not [defined libs_for_gcc]] then
 #line 3 "test.in"
-<TAB>libs_for_gcc = -lgnu;
+        libs_for_gcc = -lgnu;
 if [not [defined normal_libs]] then
 #line 4 "test.in"
-<TAB>normal_libs = ;
+        normal_libs = ;
 
 #if [in [CC] gcc ]
 foo: [objects]
 {
-#line 8 "test.in"
-<TAB>[CC] -o foo [objects] [libs_for_gcc];
+#line 7 "test.in"
+        [CC] -o foo [objects] [libs_for_gcc];
 }
 #else
-#line 10 "test.in"
+#line 9 "test.in"
 foo: [objects]
 {
-#line 11 "test.in"
-<TAB>[CC] -o foo [objects] [normals_libs];
+#line 9 "test.in"
+        [CC] -o foo [objects] [normals_libs];
 }
 #endif
 fubar
@@ -126,7 +122,7 @@ if test $? -ne 0 ; then fail; fi
 #
 # test the make2cook functionality
 #
-sed "s|<TAB>|$TAB|g" > test.in << 'fubar'
+cat > test.in << 'fubar'
 .SUFFIXES:
 
 libs_for_gcc = -lgnu
@@ -138,42 +134,41 @@ else
 libs = $(libs_for_gcc)
 endif
 
-foo: $(objects)
-<TAB>$(CC) -o foo $(objects) $(libs)
+foo: $(objects);$(CC) -o foo $(objects) $(libs)
 fubar
 if test $? -ne 0 ; then fail; fi
 
-sed "s|<TAB>|$TAB|g" > test.ok << 'fubar'
+cat > test.ok << 'fubar'
 if [not [defined objects]] then
-<TAB>objects = [getenv objects];
+        objects = [getenv objects];
 if [not [defined CC]] then
 {
-<TAB>CC = [getenv CC];
-<TAB>if [not [CC]] then
-<TAB><TAB>CC = cc;
+        CC = [getenv CC];
+        if [not [CC]] then
+                CC = cc;
 }
 
 if [not [defined libs_for_gcc]] then
 #line 3 "test.in"
-<TAB>libs_for_gcc = -lgnu;
+        libs_for_gcc = -lgnu;
 if [not [defined normal_libs]] then
 #line 4 "test.in"
-<TAB>normal_libs = ;
+        normal_libs = ;
 
 #if [not [in [CC] gcc ] ]
 if [not [defined libs]] then
 #line 7 "test.in"
-<TAB>libs = [normal_libs];
+        libs = [normal_libs];
 #else
 if [not [defined libs]] then
 #line 9 "test.in"
-<TAB>libs = [libs_for_gcc];
+        libs = [libs_for_gcc];
 #endif
 
 foo: [objects]
 {
-#line 13 "test.in"
-<TAB>[CC] -o foo [objects] [libs];
+#line 12 "test.in"
+        [CC] -o foo [objects] [libs];
 }
 fubar
 if test $? -ne 0 ; then fail; fi
@@ -187,7 +182,7 @@ if test $? -ne 0 ; then fail; fi
 #
 # test the make2cook functionality
 #
-sed "s|<TAB>|$TAB|g" > test.in << 'fubar'
+cat > test.in << 'fubar'
 .SUFFIXES:
 
 ifndef slartibartfast
@@ -198,24 +193,23 @@ else
 libs = $(libs_for_gcc)
 endif
 
-foo: $(objects)
-<TAB>$(CC) -o foo $(objects) $(libs)
+foo: $(objects);$(CC) -o foo $(objects) $(libs)
 endif
 fubar
 if test $? -ne 0 ; then fail; fi
 
-sed "s|<TAB>|$TAB|g" > test.ok << 'fubar'
+cat > test.ok << 'fubar'
 if [not [defined objects]] then
-<TAB>objects = [getenv objects];
+        objects = [getenv objects];
 if [not [defined libs_for_gcc]] then
-<TAB>libs_for_gcc = [getenv libs_for_gcc];
+        libs_for_gcc = [getenv libs_for_gcc];
 if [not [defined normal_libs]] then
-<TAB>normal_libs = [getenv normal_libs];
+        normal_libs = [getenv normal_libs];
 if [not [defined CC]] then
 {
-<TAB>CC = [getenv CC];
-<TAB>if [not [CC]] then
-<TAB><TAB>CC = cc;
+        CC = [getenv CC];
+        if [not [CC]] then
+                CC = cc;
 }
 #line 3 "test.in"
 #if [not [defined slartibartfast ] ]
@@ -223,17 +217,17 @@ if [not [defined CC]] then
 #if [not [in [CC] gcc ] ]
 if [not [defined libs]] then
 #line 6 "test.in"
-<TAB>libs = [normal_libs];
+        libs = [normal_libs];
 #else
 if [not [defined libs]] then
 #line 8 "test.in"
-<TAB>libs = [libs_for_gcc];
+        libs = [libs_for_gcc];
 #endif
 
 foo: [objects]
 {
-#line 12 "test.in"
-<TAB>[CC] -o foo [objects] [libs];
+#line 11 "test.in"
+        [CC] -o foo [objects] [libs];
 }
 #endif
 fubar
@@ -263,33 +257,33 @@ endif
 fubar
 if test $? -ne 0 ; then fail; fi
 
-sed "s|<TAB>|$TAB|g" > test.ok << 'fubar'
+cat > test.ok << 'fubar'
 if [not [defined normals_libs]] then
-<TAB>normals_libs = [getenv normals_libs];
+        normals_libs = [getenv normals_libs];
 if [not [defined CC]] then
 {
-<TAB>CC = [getenv CC];
-<TAB>if [not [CC]] then
-<TAB><TAB>CC = cc;
+        CC = [getenv CC];
+        if [not [CC]] then
+                CC = cc;
 }
 if [not [defined objects]] then
-<TAB>objects = [getenv objects];
+        objects = [getenv objects];
 
 if [not [defined libs_for_gcc]] then
 #line 3 "test.in"
-<TAB>libs_for_gcc = -lgnu;
+        libs_for_gcc = -lgnu;
 if [not [defined normal_libs]] then
 #line 4 "test.in"
-<TAB>normal_libs = ;
+        normal_libs = ;
 
 foo: [objects]
 {
 #line 7 "test.in"
-<TAB>#if [in [CC] gcc ]
-<TAB>[CC] -o foo [objects] [libs_for_gcc];
-<TAB>#else
-<TAB>[CC] -o foo [objects] [normals_libs];
-<TAB>#endif
+        #if [in [CC] gcc ]
+        [CC] -o foo [objects] [libs_for_gcc];
+        #else
+        [CC] -o foo [objects] [normals_libs];
+        #endif
 }
 fubar
 if test $? -ne 0 ; then fail; fi
