@@ -5,7 +5,7 @@
 #
 #       This program is free software; you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
-#       the Free Software Foundation; either version 2 of the License, or
+#       the Free Software Foundation; either version 3 of the License, or
 #       (at your option) any later version.
 #
 #       This program is distributed in the hope that it will be useful,
@@ -14,10 +14,8 @@
 #       GNU General Public License for more details.
 #
 #       You should have received a copy of the GNU General Public License
-#       along with this program; if not, write to the Free Software
-#       Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
-#
-# MANIFEST: Test the make2cook functionality
+#       along with this program. If not, see
+#       <http://www.gnu.org/licenses/>.
 #
 work=${COOK_TMP:-/tmp}/$$
 PAGER=cat
@@ -75,19 +73,16 @@ distribute := $(strip $(distribute))
 fubar
 if test $? -ne 0 ; then fail; fi
 
-TAB=`awk 'BEGIN{printf("\11")}' /dev/null`
-test $? -eq 0 || fail
-
-sed "s|<TAB>|$TAB|g" > test.ok << 'fubar'
+cat > test.ok << 'fubar'
 if [not [defined distribute]] then
 #line 1 "test.in"
-<TAB>distribute = README INSTALL NOTES COPYING.LIB COPYING ChangeLog NEWS
-<TAB>Makefile Makeconfig Makerules Rules Make-dist MakeTAGS
-<TAB>ansidecl.h mkinstalldirs move-if-change install.sh
-<TAB>configure configure.in aclocal.m4 config.sub config.guess
-<TAB>munch-tmpl.c munch.awk gnu-stabs.h sysdep.h set-hooks.h;
+        distribute = README INSTALL NOTES COPYING.LIB COPYING ChangeLog NEWS
+        Makefile Makeconfig Makerules Rules Make-dist MakeTAGS
+        ansidecl.h mkinstalldirs move-if-change install.sh
+        configure configure.in aclocal.m4 config.sub config.guess
+        munch-tmpl.c munch.awk gnu-stabs.h sysdep.h set-hooks.h;
 if [not [defined distribute]] then
-<TAB>distribute = [strip [distribute]];
+        distribute = [strip [distribute]];
 fubar
 if test $? -ne 0 ; then fail; fi
 
