@@ -5,7 +5,7 @@
 #
 #       This program is free software; you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
-#       the Free Software Foundation; either version 2 of the License, or
+#       the Free Software Foundation; either version 3 of the License, or
 #       (at your option) any later version.
 #
 #       This program is distributed in the hope that it will be useful,
@@ -14,10 +14,8 @@
 #       GNU General Public License for more details.
 #
 #       You should have received a copy of the GNU General Public License
-#       along with this program; if not, write to the Free Software
-#       Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
-#
-# MANIFEST: Test the make2cook define functionality
+#       along with this program. If not, see
+#       <http://www.gnu.org/licenses/>.
 #
 work=${COOK_TMP:-/tmp}/$$
 PAGER=cat
@@ -59,13 +57,10 @@ COOK_MESSAGE_LIBRARY=$work/no-such-dir
 export COOK_MESSAGE_LIBRARY
 unset LANG
 
-TAB=`awk 'BEGIN{printf("\11")}' /dev/null`
-test $? -eq 0 || fail
-
 #
 # test the make2cook define functionality
 #
-sed "s|<TAB>|$TAB|g" > test.in << 'fubar'
+cat > test.in << 'fubar'
 .SUFFIXES:
 define \n
 
@@ -74,26 +69,26 @@ endef
 sysdep-subdirs := $(subst $(\n), ,$(sysdep-subdirs))
 
 # These are the subdirectories containing the library source.
-+ansi_dirs<TAB>:= assert ctype locale math setjmp \
-<TAB><TAB>signal stdio stdlib malloc string time
++ansi_dirs := assert ctype locale math setjmp \
+              signal stdio stdlib malloc string time
 fubar
 if test $? -ne 0 ; then fail; fi
 
-sed "s|<TAB>|$TAB|g" > test.ok << 'fubar'
+cat > test.ok << 'fubar'
 if [not [defined \\n]] then
 #line 2 "test.in"
-<TAB>\\n =
-<TAB>\n;
+        \\n =
+        \n;
 if [not [defined sysdep-subdirs]] then
 
-<TAB>sysdep-subdirs = [subst [\\n] " " [sysdep-subdirs]];
+        sysdep-subdirs = [subst [\\n] " " [sysdep-subdirs]];
 /*
  * These are the subdirectories containing the library source.
  */
 if [not [defined +ansi_dirs]] then
 #line 9 "test.in"
-<TAB>+ansi_dirs = assert ctype locale math setjmp
-<TAB>signal stdio stdlib malloc string time;
+        +ansi_dirs = assert ctype locale math setjmp
+        signal stdio stdlib malloc string time;
 fubar
 if test $? -ne 0 ; then fail; fi
 
