@@ -5,7 +5,7 @@
 #
 #       This program is free software; you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
-#       the Free Software Foundation; either version 2 of the License, or
+#       the Free Software Foundation; either version 3 of the License, or
 #       (at your option) any later version.
 #
 #       This program is distributed in the hope that it will be useful,
@@ -14,10 +14,8 @@
 #       GNU General Public License for more details.
 #
 #       You should have received a copy of the GNU General Public License
-#       along with this program; if not, write to the Free Software
-#       Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
-#
-# MANIFEST: Test the make2cook functionality
+#       along with this program. If not, see
+#       <http://www.gnu.org/licenses/>.
 #
 work=${COOK_TMP:-/tmp}/$$
 PAGER=cat
@@ -85,14 +83,11 @@ endif
 fubar
 if test $? -ne 0 ; then no_result; fi
 
-TAB=`awk 'BEGIN{printf("\11")}' /dev/null`
-test $? -eq 0 || no_result
-
-sed "s|<TAB>|$TAB|g" > test.ok << 'fubar'
+cat > test.ok << 'fubar'
 if [not [defined ..]] then
-<TAB>.. = [getenv ..];
+        .. = [getenv ..];
 if [not [defined ARCH]] then
-<TAB>ARCH = [getenv ARCH];
+        ARCH = [getenv ARCH];
 #line 0 "test.in"
 /*
  * Directory for object files and libc.a.  If this is not defined, the
@@ -105,11 +100,11 @@ if [not [defined ARCH]] then
 #if [in [filter /% [ARCH]] "" ]
 if [not [defined objdir]] then
 #line 7 "test.in"
-<TAB>objdir = [..][ARCH];
+        objdir = [..][ARCH];
 #else
 if [not [defined objdir]] then
 #line 9 "test.in"
-<TAB>objdir = [ARCH];
+        objdir = [ARCH];
 #endif
 #endif
 fubar
