@@ -5,7 +5,7 @@
 #
 #       This program is free software; you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
-#       the Free Software Foundation; either version 2 of the License, or
+#       the Free Software Foundation; either version 3 of the License, or
 #       (at your option) any later version.
 #
 #       This program is distributed in the hope that it will be useful,
@@ -14,10 +14,8 @@
 #       GNU General Public License for more details.
 #
 #       You should have received a copy of the GNU General Public License
-#       along with this program; if not, write to the Free Software
-#       Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
-#
-# MANIFEST: Test the make2cook functionality
+#       along with this program. If not, see
+#       <http://www.gnu.org/licenses/>.
 #
 work=${COOK_TMP:-/tmp}/$$
 PAGER=cat
@@ -67,9 +65,6 @@ COOK_MESSAGE_LIBRARY=$work/no-such-dir
 export COOK_MESSAGE_LIBRARY
 unset LANG
 
-TAB=`awk 'BEGIN{printf("\11")}' /dev/null`
-test $? -eq 0 || no_result
-
 #
 # test the make2cook functionality
 #
@@ -79,10 +74,10 @@ close-check-inhibit-asm = ;; esac
 fubar
 if test $? -ne 0 ; then no_result; fi
 
-sed "s|<TAB>|$TAB|g" > test.ok << 'fubar'
+cat > test.ok << 'fubar'
 if [not [defined close-check-inhibit-asm]] then
 #line 2 "test.in"
-<TAB>close-check-inhibit-asm = \;\; esac;
+        close-check-inhibit-asm = \;\; esac;
 fubar
 if test $? -ne 0 ; then no_result; fi
 
@@ -102,20 +97,20 @@ $(patsubst %,$(libc.a:a=)\%(%),$(notdir $(objects))): $(objpfx)stamp-$(subdir);
 fubar
 if test $? -ne 0 ; then no_result; fi
 
-sed "s|<TAB>|$TAB|g" > test.ok << 'fubar'
+cat > test.ok << 'fubar'
 if [not [defined subdir]] then
-<TAB>subdir = [getenv subdir];
+        subdir = [getenv subdir];
 if [not [defined objpfx]] then
-<TAB>objpfx = [getenv objpfx];
+        objpfx = [getenv objpfx];
 if [not [defined objects]] then
-<TAB>objects = [getenv objects];
+        objects = [getenv objects];
 if [not [defined libc.a]] then
-<TAB>libc.a = [getenv libc.a];
+        libc.a = [getenv libc.a];
 #line 2 "test.in"
 +libobjs = [patsubst % [libc.a](%) [notdir [objects]]];
 [patsubst % [patsubst %0%.a %0% [libc.a]]\\%(%) [notdir [objects]]]: [objpfx]stamp-[subdir]
 {
-<TAB>;
+        ;
 }
 fubar
 if test $? -ne 0 ; then no_result; fi
