@@ -5,7 +5,7 @@
 #
 #       This program is free software; you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
-#       the Free Software Foundation; either version 2 of the License, or
+#       the Free Software Foundation; either version 3 of the License, or
 #       (at your option) any later version.
 #
 #       This program is distributed in the hope that it will be useful,
@@ -14,10 +14,8 @@
 #       GNU General Public License for more details.
 #
 #       You should have received a copy of the GNU General Public License
-#       along with this program; if not, write to the Free Software
-#       Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
-#
-# MANIFEST: Test the make2cook functionality
+#       along with this program. If not, see
+#       <http://www.gnu.org/licenses/>.
 #
 work=${COOK_TMP:-/tmp}/$$
 PAGER=cat
@@ -67,7 +65,7 @@ COOK_MESSAGE_LIBRARY=$work/no-such-dir
 export COOK_MESSAGE_LIBRARY
 unset LANG
 
-TAB=`awk 'BEGIN{printf("\11")}' /dev/null`
+TAB=`awk 'BEGIN{printf("%c",9)}' /dev/null`
 test $? -eq 0 || no_result
 
 #
@@ -80,10 +78,10 @@ a: b
 fubar
 if test $? -ne 0 ; then no_result; fi
 
-sed "s|<TAB>|$TAB|g" > test.ok << 'fubar'
+cat > test.ok << 'fubar'
 a: b
 {
-<TAB>$ a(b,c);
+        $ a(b,c);
 }
 fubar
 if test $? -ne 0 ; then no_result; fi
@@ -106,13 +104,13 @@ a: b
 fubar
 if test $? -ne 0 ; then no_result; fi
 
-sed "s|<TAB>|$TAB|g" > test.ok << 'fubar'
+cat > test.ok << 'fubar'
 a: b
 {
-<TAB>/*
-<TAB> * this is a comment
-<TAB> */
-<TAB>cat [resolve [need]] > [target];
+        /*
+         * this is a comment
+         */
+        cat [resolve [need]] > [target];
 }
 fubar
 if test $? -ne 0 ; then no_result; fi
@@ -134,23 +132,23 @@ all: all.tex
 fubar
 if test $? -ne 0 ; then no_result; fi
 
-sed "s|<TAB>|$TAB|g" > test.ok << 'fubar'
+cat > test.ok << 'fubar'
 if [not [defined CWEAVE]] then
 {
-<TAB>CWEAVE = [getenv CWEAVE];
-<TAB>if [not [CWEAVE]] then
-<TAB><TAB>CWEAVE = cweave;
+        CWEAVE = [getenv CWEAVE];
+        if [not [CWEAVE]] then
+                CWEAVE = cweave;
 }
 
 all: all.tex;
 
 %0%.tex: %0%.w
 {
-<TAB>[CWEAVE] [resolve [head [need]]] - [target];
+        [CWEAVE] [resolve [head [need]]] - [target];
 }
 %0%.tex: %0%.w %0%.ch
 {
-<TAB>[CWEAVE] [resolve [need]] [target];
+        [CWEAVE] [resolve [need]] [target];
 }
 fubar
 if test $? -ne 0 ; then no_result; fi
@@ -173,15 +171,15 @@ barf = $($(foo)bar)
 fubar
 if test $? -ne 0 ; then no_result; fi
 
-sed "s|<TAB>|$TAB|g" > test.ok << 'fubar'
+cat > test.ok << 'fubar'
 if [not [defined [foo]bar]] then
-<TAB>[foo]bar = [getenv [foo]bar];
+        [foo]bar = [getenv [foo]bar];
 if [not [defined foo]] then
-<TAB>foo = [getenv foo];
+        foo = [getenv foo];
 
 if [not [defined barf]] then
 #line 2 "test.in"
-<TAB>barf = [[foo]bar];
+        barf = [[foo]bar];
 fubar
 if test $? -ne 0 ; then no_result; fi
 
