@@ -5,7 +5,7 @@
 #
 #       This program is free software; you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
-#       the Free Software Foundation; either version 2 of the License, or
+#       the Free Software Foundation; either version 3 of the License, or
 #       (at your option) any later version.
 #
 #       This program is distributed in the hope that it will be useful,
@@ -14,10 +14,8 @@
 #       GNU General Public License for more details.
 #
 #       You should have received a copy of the GNU General Public License
-#       along with this program; if not, write to the Free Software
-#       Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
-#
-# MANIFEST: Test the graph functionality
+#       along with this program. If not, see
+#       <http://www.gnu.org/licenses/>.
 #
 work=${COOK_TMP:-/tmp}/$$
 PAGER=cat
@@ -139,18 +137,15 @@ if test $? -ne 0 ; then fail; fi
 $bin/cook -nl -script > test.out
 if test $? -ne 0 ; then fail; fi
 
-TAB=`awk 'BEGIN{printf("\11")}' /dev/null`
-test $? -eq 0 || no_result
-
-sed "s|<TAB>|$TAB|g" > test.ok << 'fubar'
+cat > test.ok << 'fubar'
 #!/bin/sh
 
 #line 12 howto.cook
 if test ! -e a.o \
-<TAB>-o ! a.o -nt a.c \
-<TAB>-o ! a.o -nt a.h \
-<TAB>-o ! a.o -nt b.h \
-<TAB>-o c.h -nt a.o
+  -o ! a.o -nt a.c \
+  -o ! a.o -nt a.h \
+  -o ! a.o -nt b.h \
+  -o c.h -nt a.o
 then
 echo 'echo a.c + a.c a.h b.h c.h > a.o'
 ( echo a.c + a.c a.h b.h c.h > a.o )
@@ -159,9 +154,9 @@ fi
 
 #line 12 howto.cook
 if test ! -e b.o \
-<TAB>-o ! b.o -nt b.c \
-<TAB>-o ! b.o -nt b.h \
-<TAB>-o ! b.o -nt c.h
+  -o ! b.o -nt b.c \
+  -o ! b.o -nt b.h \
+  -o ! b.o -nt c.h
 then
 echo 'echo b.c + b.c b.h c.h > b.o'
 ( echo b.c + b.c b.h c.h > b.o )
@@ -170,8 +165,8 @@ fi
 
 #line 12 howto.cook
 if test ! -e c.o \
-<TAB>-o ! c.o -nt c.c \
-<TAB>-o ! c.o -nt c.h
+  -o ! c.o -nt c.c \
+  -o ! c.o -nt c.h
 then
 echo 'echo c.c + c.c c.h > c.o'
 ( echo c.c + c.c c.h > c.o )
@@ -180,9 +175,9 @@ fi
 
 #line 17 howto.cook
 if test ! -e prog \
-<TAB>-o ! prog -nt a.o \
-<TAB>-o ! prog -nt b.o \
-<TAB>-o ! prog -nt c.o
+  -o ! prog -nt a.o \
+  -o ! prog -nt b.o \
+  -o ! prog -nt c.o
 then
 echo 'echo a.o b.o c.o > prog'
 ( echo a.o b.o c.o > prog )
