@@ -5,7 +5,7 @@
 #
 #       This program is free software; you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
-#       the Free Software Foundation; either version 2 of the License, or
+#       the Free Software Foundation; either version 3 of the License, or
 #       (at your option) any later version.
 #
 #       This program is distributed in the hope that it will be useful,
@@ -14,10 +14,8 @@
 #       GNU General Public License for more details.
 #
 #       You should have received a copy of the GNU General Public License
-#       along with this program; if not, write to the Free Software
-#       Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
-#
-# MANIFEST: Test the make2cook -nir functionality
+#       along with this program. If not, see
+#       <http://www.gnu.org/licenses/>.
 #
 work=${COOK_TMP:-/tmp}/$$
 PAGER=cat
@@ -67,29 +65,25 @@ if test $? -ne 0 ; then no_result; fi
 #
 COOK_MESSAGE_LIBRARY=$work/no-such-dir
 
-TAB=`awk 'BEGIN{printf("\11")}' /dev/null`
-if test $? -ne 0 ; then no_result; fi
-
 #
 # test the make2cook -nir functionality
 #
-sed "s|<TAB>|$TAB|g" > makefile << 'fubar'
-test: test.o
-<TAB>$(CC) -o $@ $^
+cat > makefile << 'fubar'
+test: test.o;$(CC) -o $@ $^
 fubar
 if test $? -ne 0 ; then no_result; fi
 
-sed "s|<TAB>|$TAB|g" > test.ok << 'fubar'
+cat > test.ok << 'fubar'
 if [not [defined CC]] then
 {
-<TAB>CC = [getenv CC];
-<TAB>if [not [CC]] then
-<TAB><TAB>CC = cc;
+        CC = [getenv CC];
+        if [not [CC]] then
+                CC = cc;
 }
 
 test: test.o
 {
-<TAB>[CC] -o [target] [resolve [need]];
+        [CC] -o [target] [resolve [need]];
 }
 fubar
 if test $? -ne 0 ; then no_result; fi
