@@ -5,7 +5,7 @@
 #
 #       This program is free software; you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
-#       the Free Software Foundation; either version 2 of the License, or
+#       the Free Software Foundation; either version 3 of the License, or
 #       (at your option) any later version.
 #
 #       This program is distributed in the hope that it will be useful,
@@ -14,10 +14,8 @@
 #       GNU General Public License for more details.
 #
 #       You should have received a copy of the GNU General Public License
-#       along with this program; if not, write to the Free Software
-#       Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
-#
-# MANIFEST: Test the cook_bom functionality
+#       along with this program. If not, see
+#       <http://www.gnu.org/licenses/>.
 #
 work=${COOK_TMP:-/tmp}/$$
 PAGER=cat
@@ -84,34 +82,31 @@ if test $? -ne 0 ; then no_result; fi
 mkdir deeper
 if test $? -ne 0 ; then no_result; fi
 
-TAB=`awk 'BEGIN{printf("\11")}' /dev/null`
-if test $? -ne 0 ; then no_result; fi
-
-sed "s|<TAB>|$TAB|g" > test.ok << 'fubar'
+cat > test.ok << 'fubar'
 .cook.bom.dir = [relative_dirname [__FILE__]];
 if [in [.cook.bom.dir] "."] then
-<TAB>.cook.bom/dir = '';
+    .cook.bom/dir = '';
 else
-<TAB>.cook.bom/dir = [.cook.bom.dir]/;
+    .cook.bom/dir = [.cook.bom.dir]/;
 
 files_in_[.cook.bom.dir] =
-<TAB>howto.cook
-<TAB>test.ok
-<TAB>;
+    howto.cook
+    test.ok
+    ;
 all_files_in_[.cook.bom.dir] = [files_in_[.cook.bom.dir]];
 
 specials_in_[.cook.bom.dir] =
-<TAB>;
+    ;
 all_specials_in_[.cook.bom.dir] = [specials_in_[.cook.bom.dir]];
 
 directories_in_[.cook.bom.dir] =
-<TAB>deeper
-<TAB>lib
-<TAB>;
+    deeper
+    lib
+    ;
 all_directories_in_[.cook.bom.dir] = [directories_in_[.cook.bom.dir]];
 
 #include-cooked-nowarn [prepost [.cook.bom/dir] /manifest.cook \
-<TAB>[directories_in_[.cook.bom.dir]]]
+    [directories_in_[.cook.bom.dir]]]
 
 /*
  * These variables must be calculated again, as the above includes will
@@ -119,29 +114,29 @@ all_directories_in_[.cook.bom.dir] = [directories_in_[.cook.bom.dir]];
  */
 .cook.bom.dir = [relative_dirname [__FILE__]];
 if [in [.cook.bom.dir] "."] then
-<TAB>.cook.bom/dir = '';
+    .cook.bom/dir = '';
 else
-<TAB>.cook.bom/dir = [.cook.bom.dir]/;
+    .cook.bom/dir = [.cook.bom.dir]/;
 
 if [defined all_files_in_[.cook.bom/dir]deeper] then
-<TAB>all_files_in_[.cook.bom.dir] +=
-<TAB><TAB>[addprefix deeper/ [all_files_in_[.cook.bom/dir]deeper]];
+    all_files_in_[.cook.bom.dir] +=
+        [addprefix deeper/ [all_files_in_[.cook.bom/dir]deeper]];
 if [defined all_specials_in_[.cook.bom/dir]deeper] then
-<TAB>all_specials_in_[.cook.bom.dir] +=
-<TAB><TAB>[addprefix deeper/ [all_specials_in_[.cook.bom/dir]deeper]];
+    all_specials_in_[.cook.bom.dir] +=
+        [addprefix deeper/ [all_specials_in_[.cook.bom/dir]deeper]];
 if [defined all_directories_in_[.cook.bom/dir]deeper] then
-<TAB>all_directories_in_[.cook.bom.dir] +=
-<TAB><TAB>[addprefix deeper/ [all_directories_in_[.cook.bom/dir]deeper]];
+    all_directories_in_[.cook.bom.dir] +=
+        [addprefix deeper/ [all_directories_in_[.cook.bom/dir]deeper]];
 
 if [defined all_files_in_[.cook.bom/dir]lib] then
-<TAB>all_files_in_[.cook.bom.dir] +=
-<TAB><TAB>[addprefix lib/ [all_files_in_[.cook.bom/dir]lib]];
+    all_files_in_[.cook.bom.dir] +=
+        [addprefix lib/ [all_files_in_[.cook.bom/dir]lib]];
 if [defined all_specials_in_[.cook.bom/dir]lib] then
-<TAB>all_specials_in_[.cook.bom.dir] +=
-<TAB><TAB>[addprefix lib/ [all_specials_in_[.cook.bom/dir]lib]];
+    all_specials_in_[.cook.bom.dir] +=
+        [addprefix lib/ [all_specials_in_[.cook.bom/dir]lib]];
 if [defined all_directories_in_[.cook.bom/dir]lib] then
-<TAB>all_directories_in_[.cook.bom.dir] +=
-<TAB><TAB>[addprefix lib/ [all_directories_in_[.cook.bom/dir]lib]];
+    all_directories_in_[.cook.bom.dir] +=
+        [addprefix lib/ [all_directories_in_[.cook.bom/dir]lib]];
 
 .cook.bom.dir = ;
 .cook.bom/dir = ;
